@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -38,14 +38,13 @@ void cons_mdep_done(void);
 int  cons_mdep_getc(void);
 int  cons_getc(void);
 unsigned cons_break(void);
+void cons_putpos(unsigned, unsigned, unsigned);
 
-void cons_err(char *mesg);
-void cons_errs(char *s, char *mesg);
-void cons_erru(unsigned long u, char *mesg);
-void cons_errss(char *s0, char *s1, char *mesg);
-void cons_errsu(char *s, unsigned long u, char *mesg);
-void cons_erruu(unsigned long u0, unsigned long u1, char *mesg);
-
-extern unsigned cons_breakcnt;
+void cons_err(char *);
+void cons_errs(char *, char *);
+void cons_erru(unsigned long, char *);
+void cons_errss(char *, char *, char *);
+void cons_errsu(char *, unsigned long, char *);
+void cons_erruu(unsigned long, unsigned long, char *);
 
 #endif /* MIDISH_CONS_H */
