@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -37,12 +37,12 @@
  * currently allowed data types are
  *	- 'nil' (ie no value)
  *	- long signed integer
- *	- string 
+ *	- string
  *	- reference, ie an identifier (function name, track name...)
  *	- an user type 'void *addr' pointer
  *	- a list of values
  */
-	 
+
 #include "dbg.h"
 #include "str.h"
 #include "cons.h"
@@ -52,9 +52,10 @@
  * allocate a new data structure and initialize it as 'nil'
  */
 struct data *
-data_newnil(void) {
+data_newnil(void)
+{
 	struct data *o;
-	o = (struct data *)mem_alloc(sizeof(struct data));
+	o = (struct data *)mem_alloc(sizeof(struct data), "data");
 	o->type = DATA_NIL;
 	o->next = NULL;
 	return o;
@@ -64,7 +65,8 @@ data_newnil(void) {
  * allocate a new data structure and initialize with the given integer
  */
 struct data *
-data_newlong(long val) {
+data_newlong(long val)
+{
 	struct data *o;
 	o = data_newnil();
 	o->val.num = val;
@@ -77,7 +79,8 @@ data_newlong(long val) {
  * given string
  */
 struct data *
-data_newstring(char *val) {
+data_newstring(char *val)
+{
 	struct data *o;
 	o = data_newnil();
 	o->val.str = str_new(val);
@@ -90,7 +93,8 @@ data_newstring(char *val) {
  * given reference
  */
 struct data *
-data_newref(char *val) {
+data_newref(char *val)
+{
 	struct data *o;
 	o = data_newnil();
 	o->val.ref = str_new(val);
@@ -105,7 +109,8 @@ data_newref(char *val) {
  * of data structures
  */
 struct data *
-data_newlist(struct data *list) {
+data_newlist(struct data *list)
+{
 	struct data *o;
 	o = data_newnil();
 	o->val.list = list;
@@ -118,7 +123,8 @@ data_newlist(struct data *list) {
  * type
  */
 struct data *
-data_newuser(void *addr) {
+data_newuser(void *addr)
+{
 	struct data *o;
 	o = data_newnil();
 	o->type = DATA_USER;
@@ -126,17 +132,32 @@ data_newuser(void *addr) {
 	return o;
 }
 
+/*
+ * allocate a new data structure and initialize with the given range
+ */
+struct data *
+data_newrange(unsigned min, unsigned max)
+{
+	struct data *o;
+	o = data_newnil();
+	o->type = DATA_RANGE;
+	o->val.range.min = min;
+	o->val.range.max = max;
+	return o;
+}
+
 /*
  * return the number of data structures contained in the given data
  * structure
  */
 unsigned
-data_numitem(struct data *o) {
+data_numitem(struct data *o)
+{
 	struct data *i;
 	unsigned n;
 
 	n = 1;
-	if (o->type == DATA_LIST) {	
+	if (o->type == DATA_LIST) {
 		for (i = o->val.list; i != NULL; i = i->next) {
 			n += data_numitem(i);
 		}
@@ -149,7 +170,8 @@ data_numitem(struct data *o) {
  * DATA_LIST) the given data structure (can be of any type)
  */
 void
-data_listadd(struct data *o, struct data *v) {
+data_listadd(struct data *o, struct data *v)
+{
 	struct data **i;
 	i = &o->val.list;
 	while (*i != NULL) {
@@ -163,7 +185,8 @@ data_listadd(struct data *o, struct data *v) {
  * remove the given data struct from the given list
  */
 void
-data_listremove(struct data *o, struct data *v) {
+data_listremove(struct data *o, struct data *v)
+{
 	struct data **i;
 	i = &o->val.list;
         while (*i != NULL) {
@@ -182,7 +205,8 @@ data_listremove(struct data *o, struct data *v) {
  * clear a data structure and set it to by of type 'DATA_NIL'
  */
 void
-data_clear(struct data *o) {
+data_clear(struct data *o)
+{
 	struct data *i, *inext;
 	switch(o->type) {
 	case DATA_STRING:
@@ -200,6 +224,7 @@ data_clear(struct data *o) {
 	case DATA_LONG:
 	case DATA_NIL:
 	case DATA_USER:
+	case DATA_RANGE:
 		break;
 	default:
 		dbg_puts("data_clear: unknown type\n");
@@ -210,15 +235,17 @@ data_clear(struct data *o) {
 }
 
 void
-data_delete(struct data *o) {
+data_delete(struct data *o)
+{
 	data_clear(o);
 	mem_free(o);
 }
 
 void
-data_dbg(struct data *o) {
+data_dbg(struct data *o)
+{
 	struct data *i;
-	
+
 	switch(o->type) {
 	case DATA_NIL:
 		dbg_puts("(nil)");
@@ -253,6 +280,11 @@ data_dbg(struct data *o) {
 		}
 		dbg_puts("}");
 		break;
+	case DATA_RANGE:
+		dbg_putu(o->val.range.min);
+		dbg_puts(":");
+		dbg_putu(o->val.range.max);
+		break;
 	default:
 		dbg_puts("(unknown type)");
 		break;
@@ -263,7 +295,8 @@ data_dbg(struct data *o) {
  * copy src into dst, never fails
  */
 void
-data_assign(struct data *dst, struct data *src) {
+data_assign(struct data *dst, struct data *src)
+{
 	struct data *n, *i, **j;
 	if (dst == src) {
 		dbg_puts("data_assign: src and dst are the same\n");
@@ -287,7 +320,7 @@ data_assign(struct data *dst, struct data *src) {
 		break;
 	case DATA_LIST:
 		dst->type = DATA_LIST;
-		dst->val.list = NULL; 
+		dst->val.list = NULL;
 		for (i = src->val.list; i != NULL; i = i->next) {
 			n = data_newnil();
 			data_assign(n, i);
@@ -297,6 +330,11 @@ data_assign(struct data *dst, struct data *src) {
 			*j = n;
 		}
 		break;
+	case DATA_RANGE:
+		dst->type = DATA_RANGE;
+		dst->val.range.min = src->val.range.min;
+		dst->val.range.max = src->val.range.max;
+		break;
 	default:
 		dbg_puts("data_assign: bad data type\n");
 		dbg_panic();
@@ -308,7 +346,8 @@ data_assign(struct data *dst, struct data *src) {
  * return 1 if op1 et op2 are identical, 0 overwise
  */
 unsigned
-data_id(struct data *op1, struct data *op2) {
+data_id(struct data *op1, struct data *op2)
+{
 	struct data *i1, *i2;
 	if (op1->type != op2->type) {
 		return 0;
@@ -336,6 +375,10 @@ data_id(struct data *op1, struct data *op2) {
 		}
 		/* not reached */
 		break;
+	case DATA_RANGE:
+		return op1->val.range.min == op2->val.range.min &&
+		    op1->val.range.max == op2->val.range.max;
+		break;
 	default:
 		dbg_puts("data_id: bad data types\n");
 		dbg_panic();
@@ -345,14 +388,15 @@ data_id(struct data *op1, struct data *op2) {
 }
 
 /*
- * return 1 if the argument is 
- *	- a ref  
- * 	- a not empty string or list 
- *	- a non-zero integer 
+ * return 1 if the argument is
+ *	- a ref
+ * 	- a not empty string or list
+ *	- a non-zero integer
  * and 0 overwise
  */
 unsigned
-data_eval(struct data *o) {
+data_eval(struct data *o)
+{
 	switch(o->type) {
 	case DATA_NIL:
 		return 0;
@@ -364,12 +408,14 @@ data_eval(struct data *o) {
 		return 1;
 	case DATA_LIST:
 		return o->val.list != NULL ? 1 : 0;
+	case DATA_RANGE:
+		return 1;
 	default:
 		dbg_puts("data_eval: bad data type\n");
 		dbg_panic();
 	}
 	/* not reached */
-	return 0;	
+	return 0;
 }
 
 
@@ -379,7 +425,8 @@ data_eval(struct data *o) {
  */
 
 unsigned
-data_neg(struct data *op1) {
+data_neg(struct data *op1)
+{
 	if (op1->type == DATA_LONG) {
 		op1->val.num = - op1->val.num;
 		return 1;
@@ -389,7 +436,8 @@ data_neg(struct data *op1) {
 }
 
 unsigned
-data_bitnot(struct data *op1) {
+data_bitnot(struct data *op1)
+{
 	if (op1->type == DATA_LONG) {
 		op1->val.num = ~ op1->val.num;
 		return 1;
@@ -399,7 +447,8 @@ data_bitnot(struct data *op1) {
 }
 
 unsigned
-data_not(struct data *op1) {
+data_not(struct data *op1)
+{
 	if (data_eval(op1)) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
@@ -408,7 +457,7 @@ data_not(struct data *op1) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
 		op1->val.num = 1;
-	}	
+	}
 	return 1;
 }
 
@@ -418,15 +467,16 @@ data_not(struct data *op1) {
  * oprator applied to the couple of arguments and stores the result in
  * the first argument. Return 1 on success, 0 on failure
  */
-unsigned 
-data_add(struct data *op1, struct data *op2) {
+unsigned
+data_add(struct data *op1, struct data *op2)
+{
 	struct data **i;
-	
+
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num += op2->val.num;
 		return 1;
 	} else if (op1->type == DATA_LIST && op2->type == DATA_LIST) {
-		/* 
+		/*
 		 * concatenate 2 lists
 		 */
 		for (i = &op1->val.list; *i != NULL; i = &(*i)->next)
@@ -440,7 +490,8 @@ data_add(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_sub(struct data *op1, struct data *op2) {
+data_sub(struct data *op1, struct data *op2)
+{
 	struct data **i, *j;
 
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
@@ -451,7 +502,7 @@ data_sub(struct data *op1, struct data *op2) {
 		 * remove from the first list all elements
 		 * that are present in the second list
 		 */
-		i = &op1->val.list; 
+		i = &op1->val.list;
 		while (*i != NULL) {
 			for (j = op2->val.list; j != NULL; j = j->next) {
 				if (data_id(*i, j)) {
@@ -473,7 +524,8 @@ data_sub(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_mul(struct data *op1, struct data *op2) {
+data_mul(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num *= op2->val.num;
 		return 1;
@@ -483,7 +535,8 @@ data_mul(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_div(struct data *op1, struct data *op2) {
+data_div(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		if (op2->val.num == 0) {
 			cons_err("division by zero");
@@ -497,7 +550,8 @@ data_div(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_mod(struct data *op1, struct data *op2) {
+data_mod(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		if (op2->val.num == 0) {
 			cons_err("division by zero");
@@ -511,7 +565,8 @@ data_mod(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_lshift(struct data *op1, struct data *op2) {
+data_lshift(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num <<= op2->val.num;
 		return 1;
@@ -521,7 +576,8 @@ data_lshift(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_rshift(struct data *op1, struct data *op2) {
+data_rshift(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num >>= op2->val.num;
 		return 1;
@@ -531,7 +587,8 @@ data_rshift(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_bitor(struct data *op1, struct data *op2) {
+data_bitor(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num |= op2->val.num;
 		return 1;
@@ -541,7 +598,8 @@ data_bitor(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_bitand(struct data *op1, struct data *op2) {
+data_bitand(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num &= op2->val.num;
 		return 1;
@@ -552,7 +610,8 @@ data_bitand(struct data *op1, struct data *op2) {
 
 
 unsigned
-data_bitxor(struct data *op1, struct data *op2) {
+data_bitxor(struct data *op1, struct data *op2)
+{
 	if (op1->type == DATA_LONG && op2->type == DATA_LONG) {
 		op1->val.num ^= op2->val.num;
 		return 1;
@@ -562,7 +621,8 @@ data_bitxor(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_eq(struct data *op1, struct data *op2) {
+data_eq(struct data *op1, struct data *op2)
+{
 	if (data_id(op1, op2)) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
@@ -571,12 +631,13 @@ data_eq(struct data *op1, struct data *op2) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
 		op1->val.num = 0;
-	}	
+	}
 	return 1;
 }
 
 unsigned
-data_neq(struct data *op1, struct data *op2) {
+data_neq(struct data *op1, struct data *op2)
+{
 	if (data_id(op1, op2)) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
@@ -585,12 +646,13 @@ data_neq(struct data *op1, struct data *op2) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
 		op1->val.num = 1;
-	}	
+	}
 	return 1;
 }
 
 unsigned
-data_lt(struct data *op1, struct data *op2) {
+data_lt(struct data *op1, struct data *op2)
+{
 	if (op1->type != DATA_LONG || op2->type != DATA_LONG) {
 		cons_err("bad types in '<'");
 		return 0;
@@ -600,7 +662,8 @@ data_lt(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_le(struct data *op1, struct data *op2) {
+data_le(struct data *op1, struct data *op2)
+{
 	if (op1->type != DATA_LONG || op2->type != DATA_LONG) {
 		cons_err("bad types in '<='");
 		return 0;
@@ -610,7 +673,8 @@ data_le(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_gt(struct data *op1, struct data *op2) {
+data_gt(struct data *op1, struct data *op2)
+{
 	if (op1->type != DATA_LONG || op2->type != DATA_LONG) {
 		cons_err("bad types in '>'");
 		return 0;
@@ -620,7 +684,8 @@ data_gt(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_ge(struct data *op1, struct data *op2) {
+data_ge(struct data *op1, struct data *op2)
+{
 	if (op1->type != DATA_LONG || op2->type != DATA_LONG) {
 		cons_err("bad types in '>='");
 		return 0;
@@ -630,7 +695,8 @@ data_ge(struct data *op1, struct data *op2) {
 }
 
 unsigned
-data_and(struct data *op1, struct data *op2) {
+data_and(struct data *op1, struct data *op2)
+{
 	if (data_eval(op1) && data_eval(op2)) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
@@ -639,12 +705,13 @@ data_and(struct data *op1, struct data *op2) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
 		op1->val.num = 0;
-	}	
+	}
 	return 1;
 }
 
 unsigned
-data_or(struct data *op1, struct data *op2) {
+data_or(struct data *op1, struct data *op2)
+{
 	if (data_eval(op1) || data_eval(op2)) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
@@ -653,7 +720,7 @@ data_or(struct data *op1, struct data *op2) {
 		data_clear(op1);
 		op1->type = DATA_LONG;
 		op1->val.num = 0;
-	}	
+	}
 	return 1;
 }
 
