@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -47,6 +47,7 @@ struct data {
 #define DATA_REF	3
 #define DATA_LIST	4
 #define DATA_USER	5
+#define DATA_RANGE	6
 	unsigned type;			/* type of the value */
 	union {
 		char *str;		/* if string */
@@ -54,6 +55,10 @@ struct data {
 		struct data *list;	/* if a list of values */
 		char *ref;		/* if a reference (name) */
 		void *user;		/* user defined */
+		struct {		/* a range */
+			unsigned min;
+			unsigned max;
+		} range;
 	} val;
 	struct data *next;
 };
@@ -64,37 +69,38 @@ struct data *data_newstring(char *);
 struct data *data_newref(char *);
 struct data *data_newlist(struct data *);
 struct data *data_newuser(void *);
-void	     data_delete(struct data *o);
-void	     data_setfield(struct data *dst, char *field);
+struct data *data_newrange(unsigned, unsigned);
+void	     data_delete(struct data *);
+void	     data_setfield(struct data *, char *);
 void	     data_dbg(struct data *);
 void	     data_listadd(struct data *, struct data *);
-void	     data_listremove(struct data *o, struct data *v);
-struct data *data_listlookup(struct data *o, struct name *ref);
+void	     data_listremove(struct data *, struct data *);
+struct data *data_listlookup(struct data *, struct name *);
 
-void	 data_assign(struct data *dst, struct data *src);
-unsigned data_eval(struct data *o);
-unsigned data_id(struct data *op1, struct data *op2);
+void	 data_assign(struct data *, struct data *);
+unsigned data_eval(struct data *);
+unsigned data_id(struct data *, struct data *);
 
-unsigned data_not(struct data *op1);
-unsigned data_and(struct data *op1, struct data *op2);
-unsigned data_or(struct data *op1, struct data *op2);
-unsigned data_eq(struct data *op1, struct data *op2);
-unsigned data_neq(struct data *op1, struct data *op2);
-unsigned data_lt(struct data *op1, struct data *op2);
-unsigned data_le(struct data *op1, struct data *op2);
-unsigned data_gt(struct data *op1, struct data *op2);
-unsigned data_ge(struct data *op1, struct data *op2);
-unsigned data_add(struct data *op1, struct data *op2);
-unsigned data_sub(struct data *op1, struct data *op2);
-unsigned data_neg(struct data *op1);
-unsigned data_mul(struct data *op1, struct data *op2);
-unsigned data_div(struct data *op1, struct data *op2);
-unsigned data_mod(struct data *op1, struct data *op2);
-unsigned data_lshift(struct data *op1, struct data *op2);
-unsigned data_rshift(struct data *op1, struct data *op2);
-unsigned data_bitand(struct data *op1, struct data *op2);
-unsigned data_bitor(struct data *op1, struct data *op2);
-unsigned data_bitxor(struct data *op1, struct data *op2);
-unsigned data_bitnot(struct data *op1);
+unsigned data_not(struct data *);
+unsigned data_and(struct data *, struct data *);
+unsigned data_or(struct data *, struct data *);
+unsigned data_eq(struct data *, struct data *);
+unsigned data_neq(struct data *, struct data *);
+unsigned data_lt(struct data *, struct data *);
+unsigned data_le(struct data *, struct data *);
+unsigned data_gt(struct data *, struct data *);
+unsigned data_ge(struct data *, struct data *);
+unsigned data_add(struct data *, struct data *);
+unsigned data_sub(struct data *, struct data *);
+unsigned data_neg(struct data *);
+unsigned data_mul(struct data *, struct data *);
+unsigned data_div(struct data *, struct data *);
+unsigned data_mod(struct data *, struct data *);
+unsigned data_lshift(struct data *, struct data *);
+unsigned data_rshift(struct data *, struct data *);
+unsigned data_bitand(struct data *, struct data *);
+unsigned data_bitor(struct data *, struct data *);
+unsigned data_bitxor(struct data *, struct data *);
+unsigned data_bitnot(struct data *);
 
 #endif /* MIDISH_DATA_H */
