@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -38,12 +38,29 @@
 void	 dbg_puts(char *);
 void	 dbg_putx(unsigned long);
 void	 dbg_putu(unsigned long);
+void	 dbg_puti(long);
 void	 dbg_panic(void);
-void	*mem_alloc(unsigned);
+void	 dbg_flush(void);
+void	*mem_alloc(unsigned, char *);
 void	 mem_free(void *);
 void	 mem_stats(void);
 unsigned mem_rnd(void);
 
+struct prof {
+	char *name;
+	unsigned n;
+	unsigned min;
+	unsigned max;
+	unsigned sum;
+	unsigned sumsqr;
+	unsigned err;
+};
+
+void prof_reset(struct prof *, char *);
+void prof_val(struct prof *, unsigned);
+void prof_dbg(struct prof *);
+
 extern unsigned mem_debug;
+extern unsigned dbg_sync;
 
 #endif /* MIDISH_DBG_H */
