@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -31,7 +31,7 @@
 #ifndef MIDISH_EV_H
 #define MIDISH_EV_H
 
-#include "default.h"
+#include "defs.h"
 
 #define EV_NULL		0		/* "null" or end-of-track */
 #define EV_TEMPO	0x2		/* tempo change */
@@ -102,36 +102,68 @@ struct ev {
 #define EV_PHASE_NEXT		2
 #define EV_PHASE_LAST		4
 
+
 /*
- * range of events
+ * range of events, the cmd argument is the event type. To facilitate
+ * matching 'struct ev' agains 'struct evspec', we try (when possible)
+ * to use the same constants. Currently this works for all events
+ * except EV_NON, EV_KAT, EV_NOFF, which all correspond to EVSPEC_NOTE
  */
 struct evspec {
-#define EVSPEC_ANY		0
-#define EVSPEC_NOTE		1
-#define EVSPEC_CTL		2
-#define EVSPEC_PC		3
-#define EVSPEC_CAT		4
-#define EVSPEC_BEND		5
-#define EVSPEC_NRPN		6
-#define EVSPEC_RPN		7
-#define EVSPEC_XCTL		8
-#define EVSPEC_XPC		9
+#define EVSPEC_EMPTY		EV_NULL
+#define EVSPEC_ANY		1
+#define EVSPEC_NOTE		EV_NON
+#define EVSPEC_CTL		EV_CTL
+#define EVSPEC_PC		EV_PC
+#define EVSPEC_CAT		EV_CAT
+#define EVSPEC_BEND		EV_BEND
+#define EVSPEC_NRPN		EV_NRPN
+#define EVSPEC_RPN		EV_RPN
+#define EVSPEC_XCTL		EV_XCTL
+#define EVSPEC_XPC		EV_XPC
 	unsigned cmd;
-	unsigned dev_min, dev_max;
-	unsigned ch_min, ch_max;
-	unsigned b0_min, b0_max;
-	unsigned b1_min, b1_max;
+	unsigned dev_min, dev_max;	/* except for EMPTY */
+	unsigned ch_min, ch_max;	/* except for EMPTY */
+	unsigned v0_min, v0_max;	/* except for EMPTY, ANY */
+	unsigned v1_min, v1_max;	/* except for EMPTY, ANY, CAT, PC */
 };
 
-void	 ev_dbg(struct ev *ev);
-unsigned ev_prio(struct ev *ev);
-unsigned ev_str2cmd(struct ev *ev, char *str);
-unsigned ev_phase(struct ev *ev);
 
-unsigned evspec_str2cmd(struct evspec *ev, char *str);
-void	 evspec_dbg(struct evspec *o);
-void	 evspec_reset(struct evspec *o);
-unsigned evspec_matchev(struct evspec *o, struct ev *e);
+/*
+ * we use a static array (indexed by 'cmd') of the following
+ * structures to lookup for events properties
+ */
+struct evinfo {
+	char *ev, *spec;
+#define EV_HAS_DEV	0x01	/* if ev->dev is used */
+#define EV_HAS_CH	0x02	/* if ev->ch is used */
+	unsigned flags;		/* bitmap of above */
+	unsigned nparams;	/* number of params (ie v0, v1) used */
+	unsigned nranges;	/* number of ranges (ie v0, v1) used */
+	unsigned v0_min;	/* min ev->v0 */
+	unsigned v0_max;	/* max ev->v0 */
+	unsigned v1_min;	/* min ev->v1 */
+	unsigned v1_max;	/* max ev->v1 */
+};
+
+extern struct evinfo evinfo[EV_NUMCMD];
+
+void	 ev_dbg(struct ev *);
+unsigned ev_prio(struct ev *);
+unsigned ev_str2cmd(struct ev *, char *);
+unsigned ev_phase(struct ev *);
+void	 ev_map(struct ev *, struct evspec *, struct evspec *, struct ev *);
+
+unsigned evspec_str2cmd(struct evspec *, char *);
+void	 evspec_dbg(struct evspec *);
+void	 evspec_reset(struct evspec *);
+unsigned evspec_matchev(struct evspec *, struct ev *);
+unsigned evspec_eq(struct evspec *, struct evspec *);
+unsigned evspec_isec(struct evspec *, struct evspec *);
+unsigned evspec_in(struct evspec *, struct evspec *);
+int	 evspec_isamap(struct evspec *, struct evspec *);
+void	 evspec_map(struct evspec *, struct evspec *,
+     struct evspec *, struct evspec *);
 
 /*
  * describes a controller number; this structures defines
@@ -143,7 +175,7 @@ struct evctl {
 	unsigned defval;	/* default value if type == EVCTL_FRAME */
 };
 
-extern	struct evctl evctl_tab[128];
+extern	struct evctl evctl_tab[EV_MAXCOARSE + 1];
 
 #define EV_CTL_ISPARAM(ev) \
 	(evctl_tab[(ev)->ctl_num].defval == EV_UNDEF)
@@ -154,17 +186,17 @@ extern	struct evctl evctl_tab[128];
 
 /*
  * return true if the given controller number is 14bit (fine)
- * and false if it is 7bit (coarse). The 'ctlbits' is 
- * a 32bit bitmap, it is stored in per-device basis in 
+ * and false if it is 7bit (coarse). The 'ctlbits' is
+ * a 32bit bitmap, it is stored in per-device basis in
  * mididev structure
  */
 #define EVCTL_ISFINE(xctlset, num)	((xctlset) & (1 << (num)))
 
-void     evctl_conf(unsigned num, char *name, unsigned defval);
-void	 evctl_unconf(unsigned i);
-unsigned evctl_lookup(char *name, unsigned *ret);
+void     evctl_conf(unsigned, char *, unsigned);
+void	 evctl_unconf(unsigned);
+unsigned evctl_lookup(char *, unsigned *);
 void	 evctl_init(void);
 void	 evctl_done(void);
-unsigned evctl_isreserved(unsigned num);
+unsigned evctl_isreserved(unsigned);
 
 #endif /* MIDISH_EV_H */
