@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -57,7 +57,7 @@
  *	there is no low-level primitives for moving forward, instead
  *	reading primitives should be used (and the result should be
  *	ignored). That's because the state list have to be kept up to
- *	date. Thus there is no way to go backward. 
+ *	date. Thus there is no way to go backward.
  *
  * Reading:
  *
@@ -87,7 +87,7 @@
  *	updated as events and blank space were read with
  *	seqptr_evget() and seqptr_ticskip()
  *
- * 
+ *
  * Common errors and pitfals
  * -------------------------
  *
@@ -99,8 +99,8 @@
  *	  rewritten. So the following loop:
  *
  *		for (;;) {
- *			st = seqptr_evdel(&sp, &slist);
- *			seqptr_evput(&sp, &st->ev);
+ *			st = seqptr_evdel(sp, &slist);
+ *			seqptr_evput(sp, &st->ev);
  *			...
  *		}
  *
@@ -109,15 +109,15 @@
  *
  *	- when rewriting a track one must use a separate statelist
  *	  for events being removed, so the seqptr->statelist is used for
- *	  writing new events. When starting rewriting a track on a 
+ *	  writing new events. When starting rewriting a track on a
  *	  given position, be sure to initialise the 'deleted events'
- *	  statelist with statelist_dup(), and not statelist_init(). 
+ *	  statelist with statelist_dup(), and not statelist_init().
  *	  Example:
  *
- *		seqptr_skip(&sp, pos);
- *		statelist_dup(&slist); 
+ *		seqptr_skip(sp, pos);
+ *		statelist_dup(&slist);
  *		for (;;) {
- *			seqptr_evdel(&sp, &slist);
+ *			seqptr_evdel(sp, &slist);
  *			...
  *		}
  *
@@ -126,13 +126,13 @@
  *	  are those managed by statelist_update() routine. So we must first
  *	  duplicate the statelist and then tag states. Example:
  *
- *		seqptr_skip(&sp, pos);
+ *		seqptr_skip(sp, pos);
  *		statelist_dup(&slist, &sp->slist);
  *		for (st = slist.first; st != NULL; st = st->next) {
  *			st->tag = ...
  *		}
  *
- *	  it is _not_ ok, to iterate over sp.statelist and then to dup it.
+ *	  it is _not_ ok, to iterate over sp->statelist and then to dup it.
  *
  *	- seqptr_tic{skip,put,del}() outdates the statelist of the
  *	  seqptr. This purges unused states and updates the
@@ -142,12 +142,12 @@
  *	  follows:
  *
  *		for (;;) {
- *			delta = seqptr_ticdel(&sp, &slist);
- *			seqptr_ticput(&sp, delta);
+ *			delta = seqptr_ticdel(sp, &slist);
+ *			seqptr_ticput(sp, delta);
  *
- *			st = seqptr_evdel(&sp, &slist);
- *			seqptr_evput(&sp, st->ev);
- *		} 
+ *			st = seqptr_evdel(sp, &slist);
+ *			seqptr_evput(sp, st->ev);
+ *		}
  *
  */
 
@@ -164,39 +164,59 @@
 
 #include "dbg.h"
 #include "track.h"
-#include "default.h"
+#include "defs.h"
 #include "frame.h"
+#include "pool.h"
+
+struct pool seqptr_pool;
+
+void
+seqptr_pool_init(unsigned size)
+{
+	pool_init(&seqptr_pool, "seqptr", sizeof(struct seqptr), size);
+}
+
+void
+seqptr_pool_done(void)
+{
+	pool_done(&seqptr_pool);
+}
 
 /*
- * initialize a seqptr structure at the beginning of 
+ * initialize a seqptr structure at the beginning of
  * the given track.
  */
-void
-seqptr_init(struct seqptr *sp, struct track *t) {
+struct seqptr *
+seqptr_new(struct track *t)
+{
+	struct seqptr *sp;
+
+	sp = (struct seqptr *)pool_new(&seqptr_pool);
 	statelist_init(&sp->statelist);
 	sp->pos = t->first;
 	sp->delta = 0;
 	sp->tic = 0;
+	return sp;
 }
 
 /*
  * release the seqptr structure, free statelist etc...
  */
 void
-seqptr_done(struct seqptr *sp) {
+seqptr_del(struct seqptr *sp)
+{
 	statelist_done(&sp->statelist);
-	sp->pos = (void *)0xdeadbeef;
-	sp->delta = 0xdeadbeef;
-	sp->tic = 0;
+	pool_del(&seqptr_pool, sp);
 }
 
-/* 
+/*
  * return the state structure of the next available event or NULL if
  * there is no next event in the current tick.  The state list is
  * updated accordingly.
  */
 struct state *
-seqptr_evget(struct seqptr *sp) {
+seqptr_evget(struct seqptr *sp)
+{
 	struct state *st;
 
 	if (sp->delta != sp->pos->delta || sp->pos->ev.cmd == EV_NULL) {
@@ -218,7 +238,8 @@ seqptr_evget(struct seqptr *sp) {
  * seqptr_evget
  */
 struct state *
-seqptr_evdel(struct seqptr *sp, struct statelist *slist) {
+seqptr_evdel(struct seqptr *sp, struct statelist *slist)
+{
 	struct state *st;
 	struct seqev *next;
 
@@ -227,7 +248,7 @@ seqptr_evdel(struct seqptr *sp, struct statelist *slist) {
 	}
 	if (slist)
 		st = statelist_update(slist, &sp->pos->ev);
-	else 
+	else
 		st = NULL;
 	next = sp->pos->next;
 	next->delta += sp->pos->delta;
@@ -245,9 +266,10 @@ seqptr_evdel(struct seqptr *sp, struct statelist *slist) {
  * updated and the state of the new event is returned.
  */
 struct state *
-seqptr_evput(struct seqptr *sp, struct ev *ev) {
+seqptr_evput(struct seqptr *sp, struct ev *ev)
+{
 	struct seqev *se;
-	
+
 	se = seqev_new();
 	se->ev = *ev;
 	se->delta = sp->delta;
@@ -268,9 +290,10 @@ seqptr_evput(struct seqptr *sp, struct ev *ev) {
  * terminated events are purged
  */
 unsigned
-seqptr_ticskip(struct seqptr *sp, unsigned max) {
+seqptr_ticskip(struct seqptr *sp, unsigned max)
+{
 	unsigned ntics;
-	
+
 	ntics = sp->pos->delta - sp->delta;
 	if (ntics > max) {
 		ntics = max;
@@ -288,7 +311,8 @@ seqptr_ticskip(struct seqptr *sp, unsigned max) {
  * seqptr_ticskip()
  */
 unsigned
-seqptr_ticdel(struct seqptr *sp, unsigned max, struct statelist *slist) {
+seqptr_ticdel(struct seqptr *sp, unsigned max, struct statelist *slist)
+{
 	unsigned ntics;
 
 	ntics = sp->pos->delta - sp->delta;
@@ -306,7 +330,8 @@ seqptr_ticdel(struct seqptr *sp, unsigned max, struct statelist *slist) {
  * insert blank space at the current position
  */
 void
-seqptr_ticput(struct seqptr *sp, unsigned ntics) {
+seqptr_ticput(struct seqptr *sp, unsigned ntics)
+{
 	if (ntics > 0) {
 		sp->pos->delta += ntics;
 		sp->delta += ntics;
@@ -319,14 +344,15 @@ seqptr_ticput(struct seqptr *sp, unsigned ntics) {
  * move forward 'ntics', if the end-of-track is reached then return
  * the number of reamaining tics. Used for reading on a track
  */
-unsigned 
-seqptr_skip(struct seqptr *sp, unsigned ntics) {
+unsigned
+seqptr_skip(struct seqptr *sp, unsigned ntics)
+{
 	unsigned delta;
 	while (ntics > 0) {
 		while (seqptr_evget(sp))
 			; /* nothing */
 		delta = seqptr_ticskip(sp, ntics);
-		/* 
+		/*
 		 * check if the end of the track was reached
 		 */
 		if (delta == 0)
@@ -341,7 +367,8 @@ seqptr_skip(struct seqptr *sp, unsigned ntics) {
  * blank space. Used for writing on a track
  */
 void
-seqptr_seek(struct seqptr *sp, unsigned ntics) {
+seqptr_seek(struct seqptr *sp, unsigned ntics)
+{
 	ntics = seqptr_skip(sp, ntics);
 	if (ntics > 0)
 		seqptr_ticput(sp, ntics);
@@ -354,7 +381,8 @@ seqptr_seek(struct seqptr *sp, unsigned ntics) {
  * if an event was generated.
  */
 unsigned
-seqptr_cancel(struct seqptr *sp, struct state *st) {
+seqptr_cancel(struct seqptr *sp, struct state *st)
+{
 	struct ev ev;
 
 	if (!EV_ISNOTE(&st->ev) && !(st->phase & EV_PHASE_LAST)) {
@@ -372,7 +400,8 @@ seqptr_cancel(struct seqptr *sp, struct state *st) {
  * Return 1 if an event was generated.
  */
 unsigned
-seqptr_restore(struct seqptr *sp, struct state *st) {
+seqptr_restore(struct seqptr *sp, struct state *st)
+{
 	struct ev ev;
 
 	if (!EV_ISNOTE(&st->ev) && !(st->phase & EV_PHASE_LAST)) {
@@ -391,7 +420,8 @@ seqptr_restore(struct seqptr *sp, struct state *st) {
  * NULL if there is no more state.
  */
 struct state *
-seqptr_rmlast(struct seqptr *sp, struct state *st) {
+seqptr_rmlast(struct seqptr *sp, struct state *st)
+{
 	struct seqev *i, *prev, *cur, *next;
 
 #ifdef FRAME_DEBUG
@@ -417,7 +447,7 @@ seqptr_rmlast(struct seqptr *sp, struct state *st) {
 			cur = i;
 		}
 	}
-	/* 
+	/*
 	 * remove the event from the track
 	 * (but not the blank space)
 	 */
@@ -450,7 +480,8 @@ seqptr_rmlast(struct seqptr *sp, struct state *st) {
  * track. Returns always NULL, for consistency with seqptr_rmlast().
  */
 struct state *
-seqptr_rmprev(struct seqptr *sp, struct state *st) {
+seqptr_rmprev(struct seqptr *sp, struct state *st)
+{
 	struct seqev *i, *next;
 
 #ifdef FRAME_DEBUG
@@ -465,7 +496,7 @@ seqptr_rmprev(struct seqptr *sp, struct state *st) {
 	i = st->pos;
 	for (;;) {
 		if (state_match(st, &i->ev)) {
-			/* 
+			/*
 			 * remove the event from the track
 			 * (but not the blank space)
 			 */
@@ -500,7 +531,10 @@ seqptr_rmprev(struct seqptr *sp, struct state *st) {
  * seqptr_evmerge2() within the same tic.
  */
 void
-seqptr_evmerge1(struct seqptr *pd, struct state *s1, struct state *s2) {
+seqptr_evmerge1(struct seqptr *pd, struct state *s1, struct state *s2)
+{
+	struct state *sd;
+
 	/*
 	 * ignore bogus events
 	 */
@@ -520,7 +554,9 @@ seqptr_evmerge1(struct seqptr *pd, struct state *s1, struct state *s2) {
 #endif
 	}
 	if (s1->tag) {
-		(void)seqptr_evput(pd, &s1->ev);
+		sd = statelist_lookup(&pd->statelist, &s1->ev);
+		if (!sd || !state_eq(sd, &s1->ev))
+			(void)seqptr_evput(pd, &s1->ev);
 	}
 }
 
@@ -532,7 +568,8 @@ seqptr_evmerge1(struct seqptr *pd, struct state *s1, struct state *s2) {
  * seqptr_evmerge1() within the same tick.
  */
 void
-seqptr_evmerge2(struct seqptr *pd, struct state *s1, struct state *s2) {
+seqptr_evmerge2(struct seqptr *pd, struct state *s1, struct state *s2)
+{
 	struct state *sd;
 
 	/*
@@ -556,7 +593,7 @@ seqptr_evmerge2(struct seqptr *pd, struct state *s1, struct state *s2) {
 				dbg_panic();
 			}
 			if (EV_ISNOTE(&s2->ev)) {
-				if (!(s1->phase & EV_PHASE_LAST)) 
+				if (!(s1->phase & EV_PHASE_LAST))
 					sd = seqptr_rmprev(pd, sd);
 			} else {
 				if (s1->flags & STATE_CHANGED)
@@ -566,8 +603,8 @@ seqptr_evmerge2(struct seqptr *pd, struct state *s1, struct state *s2) {
 		}
 		s2->tag = 1;
 	} else if (s2->phase & EV_PHASE_NEXT) {
-		/* 
-		 * nothing to do, conflicts already handled 
+		/*
+		 * nothing to do, conflicts already handled
 		 */
 	} else if (s2->phase & EV_PHASE_LAST) {
 		if (s1 && !EV_ISNOTE(&s1->ev)) {
@@ -590,18 +627,19 @@ seqptr_evmerge2(struct seqptr *pd, struct state *s1, struct state *s2) {
 /*
  * Merge track "src" (high priority) in track "dst" (low prority)
  * resolving all conflicts, so that "dst" is consistent.
- */	
+ */
 void
-track_merge(struct track *dst, struct track *src) {
+track_merge(struct track *dst, struct track *src)
+{
 	struct state *s1, *s2;
-	struct seqptr p2, pd;
+	struct seqptr *p2, *pd;
 	struct statelist orglist;
 	unsigned delta1, delta2, deltad;
 
-	seqptr_init(&pd, dst);
-	seqptr_init(&p2, src);
+	pd = seqptr_new(dst);
+	p2 = seqptr_new(src);
 	statelist_init(&orglist);
-	
+
 	for (;;) {
 		/*
 		 * remove all events from 'dst' and put them back on
@@ -611,11 +649,11 @@ track_merge(struct track *dst, struct track *src) {
 		 * 'dst' track.
 		 */
 		for(;;) {
-			s1 = seqptr_evdel(&pd, &orglist);
+			s1 = seqptr_evdel(pd, &orglist);
 			if (s1 == NULL)
 				break;
-			s2 = statelist_lookup(&p2.statelist, &s1->ev);
-			seqptr_evmerge1(&pd, s1, s2);
+			s2 = statelist_lookup(&p2->statelist, &s1->ev);
+			seqptr_evmerge1(pd, s1, s2);
 		}
 
 		/*
@@ -623,21 +661,21 @@ track_merge(struct track *dst, struct track *src) {
 		 * with the original state of 'dst'.
 		 */
 		for (;;) {
-			s2 = seqptr_evget(&p2);
+			s2 = seqptr_evget(p2);
 			if (s2 == NULL)
 				break;
 			s1 = statelist_lookup(&orglist, &s2->ev);
-			seqptr_evmerge2(&pd, s1, s2);
+			seqptr_evmerge2(pd, s1, s2);
 		}
-		
+
 		/*
 		 * move to the next non empty tick: the next tic is the
 		 * smaller position of the next event of each track
 		 */
-		delta1 = pd.pos->delta - pd.delta;
-		delta2 = p2.pos->delta - p2.delta;
+		delta1 = pd->pos->delta - pd->delta;
+		delta2 = p2->pos->delta - p2->delta;
 		if (delta1 > 0) {
-			deltad = delta1; 
+			deltad = delta1;
 			if (delta2 > 0 && delta2 < deltad)
 				deltad = delta2;
 		} else if (delta2 > 0) {
@@ -646,14 +684,14 @@ track_merge(struct track *dst, struct track *src) {
 			/* both delta1 and delta2 are zero */
 			break;
 		}
-		(void)seqptr_ticskip(&p2, deltad);
-		(void)seqptr_ticdel(&pd, deltad, &orglist);
-		seqptr_ticput(&pd, deltad);
+		(void)seqptr_ticskip(p2, deltad);
+		(void)seqptr_ticdel(pd, deltad, &orglist);
+		seqptr_ticput(pd, deltad);
 	}
 
 	statelist_done(&orglist);
-	seqptr_done(&p2);
-	seqptr_done(&pd);
+	seqptr_del(p2);
+	seqptr_del(pd);
 	track_chomp(dst);
 }
 
@@ -662,46 +700,49 @@ track_merge(struct track *dst, struct track *src) {
  * consistent: notes are always completely copied/moved/erased and
  * controllers (and other) are cut when necessary
  *
- * if the 'copy' flag is set, then the selection is copied in 
+ * if the 'copy' flag is set, then the selection is copied in
  * track 'dst'. If 'blank' flag is set, then the selection is
  * cleanly removed from the 'src' track
  */
 void
-track_move(struct track *src, unsigned start, unsigned len, 
+track_move(struct track *src, unsigned start, unsigned len,
     struct evspec *es, struct track *dst, unsigned copy, unsigned blank) {
 	unsigned delta;
-	struct seqptr sp, dp;		/* current src & dst track states */
+	struct seqptr *sp, *dp;		/* current src & dst track states */
 	struct statelist slist;		/* original src track state */
 	struct state *st;
 
 #define TAG_KEEP	1		/* frame is not erased */
 #define TAG_COPY	2		/* frame is copied */
 
+	/* please gcc */
+	sp = dp = NULL;
+
 	if (len == 0)
 		return;
 	if (copy) {
 		track_clear(dst);
-		seqptr_init(&dp, dst);
+		dp = seqptr_new(dst);
 	}
-	seqptr_init(&sp, src);
-	
+	sp = seqptr_new(src);
+
 	/*
 	 * go to the start position and tag all frames as
 	 * not being copied and not being erased
 	 */
-	(void)seqptr_skip(&sp, start);
-	statelist_dup(&slist, &sp.statelist);
+	(void)seqptr_skip(sp, start);
+	statelist_dup(&slist, &sp->statelist);
 	for (st = slist.first; st != NULL; st = st->next) {
        		st->tag = TAG_KEEP;
 	}
-	
+
 	/*
 	 * cancel/tag frames that will be erased (blank only)
 	 */
 	if (blank) {
 		for (st = slist.first; st != NULL; st = st->next) {
 			if (state_inspec(st, es) &&
-			    seqptr_cancel(&sp, st))
+			    seqptr_cancel(sp, st))
 				st->tag &= ~TAG_KEEP;
 		}
 	}
@@ -713,7 +754,7 @@ track_move(struct track *src, unsigned start, unsigned len,
 	 *
 	 */
 	for (;;) {
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if ((st->phase & EV_PHASE_FIRST) ||
@@ -726,12 +767,12 @@ track_move(struct track *src, unsigned start, unsigned len,
 			st->tag &= ~TAG_KEEP;
 		}
 		if (copy && (st->tag & TAG_COPY))
-			seqptr_evput(&dp, &st->ev);
+			seqptr_evput(dp, &st->ev);
 		if (!blank || (st->tag & TAG_KEEP)) {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 	}
-	
+
 	/*
 	 * in the copy, restore frames that weren't updated by the
 	 * first tic.
@@ -740,38 +781,37 @@ track_move(struct track *src, unsigned start, unsigned len,
 		for (st = slist.first; st != NULL; st = st->next) {
 			if (!state_inspec(st, es))
 				continue;
-			if (!(st->tag & TAG_COPY) && 
-			    seqptr_restore(&dp, st)) {
+			if (!(st->tag & TAG_COPY) && seqptr_restore(dp, st)) {
 				st->tag |= TAG_COPY;
 			}
 		}
 	}
-	
+
 	/*
 	 * tag/copy/erase frames during 'len' tics
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, len, &slist);
+		delta = seqptr_ticdel(sp, len, &slist);
 		if (copy)
-			seqptr_ticput(&dp, delta);
-		seqptr_ticput(&sp, delta);
+			seqptr_ticput(dp, delta);
+		seqptr_ticput(sp, delta);
 		len -= delta;
 		if (len == 0)
 			break;
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST) {
 			st->tag = state_inspec(st, es) ? TAG_COPY : TAG_KEEP;
 		}
 		if (copy && (st->tag & TAG_COPY)) {
-			seqptr_evput(&dp, &st->ev);
+			seqptr_evput(dp, &st->ev);
 		}
 		if (!blank || (st->tag & TAG_KEEP)) {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 	}
-	
+
 	/*
 	 * cancel all copied frames (that are tagged).
 	 * cancelled frames are untagged, so they will stop
@@ -779,7 +819,7 @@ track_move(struct track *src, unsigned start, unsigned len,
 	 */
 	if (copy) {
 		for (st = slist.first; st != NULL; st = st->next) {
-			if (seqptr_cancel(&dp, st))
+			if (seqptr_cancel(dp, st))
 				st->tag &= ~TAG_COPY;
 		}
 	}
@@ -791,7 +831,7 @@ track_move(struct track *src, unsigned start, unsigned len,
 	 * avoid being restored
 	 */
 	for (;;) {
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if ((st->phase & EV_PHASE_FIRST) ||
@@ -801,33 +841,33 @@ track_move(struct track *src, unsigned start, unsigned len,
 		if (st->phase & EV_PHASE_FIRST)
 			st->tag &= ~TAG_COPY;
 		if (copy && (st->tag & TAG_COPY)) {
-			seqptr_evput(&dp, &st->ev);
+			seqptr_evput(dp, &st->ev);
 		}
 		if (!blank || (st->tag & TAG_KEEP)) {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
-			
+
 	}
 
 	/*
 	 * retore/tag frames that are not tagged.
 	 */
 	for (st = slist.first; st != NULL; st = st->next) {
-		if (!(st->tag & TAG_KEEP) && seqptr_restore(&sp, st)) {
+		if (!(st->tag & TAG_KEEP) && seqptr_restore(sp, st)) {
 			st->tag |= TAG_KEEP;
 		}
 	}
-	
+
 	/*
 	 * copy frames for whose state couldn't be
 	 * canceled (note events)
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, ~0U, &slist);
+		delta = seqptr_ticdel(sp, ~0U, &slist);
 		if (copy)
-			seqptr_ticput(&dp, delta);
-		seqptr_ticput(&sp, delta);
-		st = seqptr_evdel(&sp, &slist);
+			seqptr_ticput(dp, delta);
+		seqptr_ticput(sp, delta);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST) {
@@ -835,17 +875,17 @@ track_move(struct track *src, unsigned start, unsigned len,
 			st->tag |= TAG_KEEP;
 		}
 		if (copy && (st->tag & TAG_COPY)) {
-			seqptr_evput(&dp, &st->ev);
+			seqptr_evput(dp, &st->ev);
 		}
 		if (!blank || (st->tag & TAG_KEEP)) {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 	}
-	
+
 	statelist_done(&slist);
-	seqptr_done(&sp);
+	seqptr_del(sp);
 	if (copy) {
-		seqptr_done(&dp);
+		seqptr_del(dp);
 		track_chomp(dst);
 	}
 	if (blank)
@@ -860,30 +900,30 @@ track_move(struct track *src, unsigned start, unsigned len,
 void
 track_quantize(struct track *src, unsigned start, unsigned len,
     unsigned offset, unsigned quant, unsigned rate) {
-	unsigned delta, tic;
+	unsigned tic, qtic;
 	struct track qt;
-	struct seqptr sp, qp;
+	struct seqptr *sp, *qp;
 	struct state *st;
 	struct statelist slist;
-	unsigned remaind; 
+	unsigned remaind;
 	unsigned fluct, notes;
-	int ofs;
+	int ofs, delta;
 
 	track_init(&qt);
-	seqptr_init(&sp, src);
-	seqptr_init(&qp, &qt);
+	sp = seqptr_new(src);
+	qp = seqptr_new(&qt);
 
 	/*
 	 * go to start position and untag all events
 	 * (tagged = will be quantized)
 	 */
-	(void)seqptr_skip(&sp, start);
-	statelist_dup(&slist, &sp.statelist);
+	(void)seqptr_skip(sp, start);
+	statelist_dup(&slist, &sp->statelist);
 	for (st = slist.first; st != NULL; st = st->next) {
 		st->tag = 0;
 	}
-	seqptr_seek(&qp, start);
-	tic = start;
+	seqptr_seek(qp, start);
+	tic = qtic = start;
 	ofs = 0;
 
 	/*
@@ -893,30 +933,31 @@ track_quantize(struct track *src, unsigned start, unsigned len,
 	fluct = 0;
 	notes = 0;
 	for (;;) {
-		delta = seqptr_ticdel(&sp, start + len - tic, &slist);
-		seqptr_ticput(&sp, delta);
-		tic += delta;	
+		delta = seqptr_ticdel(sp, start + len - tic, &slist);
+		seqptr_ticput(sp, delta);
+		tic += delta;
 		if (tic >= start + len)
 			break;
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 
-		delta -= ofs;
 		remaind = quant != 0 ? (tic - start + offset) % quant : 0;
 		if (remaind < quant / 2) {
 			ofs = - ((remaind * rate + 99) / 100);
 		} else {
 			ofs = ((quant - remaind) * rate + 99) / 100;
 		}
+
+		delta = tic + ofs - qtic;
 #ifdef FRAME_DEBUG
-		if (ofs < 0 && delta < (unsigned)-ofs) {
-			dbg_puts("track_quantize: delta < -ofs\n");
+		if (delta < 0) {
+			dbg_puts("track_quantize: delta < 0\n");
 			dbg_panic();
 		}
 #endif
-		delta += ofs;
-		seqptr_ticput(&qp, delta);
+		seqptr_ticput(qp, delta);
+		qtic += delta;
 
 		if (st->phase & EV_PHASE_FIRST) {
 			if (EV_ISNOTE(&st->ev)) {
@@ -928,34 +969,34 @@ track_quantize(struct track *src, unsigned start, unsigned len,
 			}
 		}
 		if (st->tag) {
-			seqptr_evput(&qp, &st->ev);
+			seqptr_evput(qp, &st->ev);
 		} else {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
-	}	    
+	}
 
 	/*
 	 * finish quantised (tagged) events
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, ~0U, &slist);
-		seqptr_ticput(&sp, delta);
-		st = seqptr_evdel(&sp, &slist);
+		delta = seqptr_ticdel(sp, ~0U, &slist);
+		seqptr_ticput(sp, delta);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST)
 			st->tag = 0;
-		seqptr_ticput(&qp, delta);
+		seqptr_ticput(qp, delta);
 		if (st->tag) {
-			seqptr_evput(&qp, &st->ev);
+			seqptr_evput(qp, &st->ev);
 		} else {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 	}
 	track_merge(src, &qt);
 	statelist_done(&slist);
-	seqptr_done(&sp);
-	seqptr_done(&qp);
+	seqptr_del(sp);
+	seqptr_del(qp);
 	track_done(&qt);
 	if (notes > 0) {
 		dbg_puts("track_quantize: fluct = ");
@@ -973,21 +1014,22 @@ track_quantize(struct track *src, unsigned start, unsigned len,
  * 'oldu' tics will correspond to 'newu'
  */
 void
-track_scale(struct track *t, unsigned oldunit, unsigned newunit) {
-	struct seqptr sp;
+track_scale(struct track *t, unsigned oldunit, unsigned newunit)
+{
+	struct seqptr *sp;
 	struct statelist slist;
 	struct state *st;
 	struct ev ev;
 	unsigned delta, err;
 
 	err = 0;
-	seqptr_init(&sp, t);
+	sp = seqptr_new(t);
 	statelist_init(&slist);
 	for (;;) {
-		delta = newunit * seqptr_ticdel(&sp, ~0U, &slist) + err;
-		seqptr_ticput(&sp, delta / oldunit);
+		delta = newunit * seqptr_ticdel(sp, ~0U, &slist) + err;
+		seqptr_ticput(sp, delta / oldunit);
 		err = delta % oldunit;
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL) {
 			break;
 		}
@@ -995,102 +1037,107 @@ track_scale(struct track *t, unsigned oldunit, unsigned newunit) {
 		case EV_TEMPO:
 			ev.cmd = st->ev.cmd;
 			ev.tempo_usec24 = st->ev.tempo_usec24 * oldunit / newunit;
-			seqptr_evput(&sp, &ev);
+			seqptr_evput(sp, &ev);
 			break;
 		case EV_TIMESIG:
 			ev.cmd = st->ev.cmd;
 			ev.timesig_beats = st->ev.timesig_beats;
 			ev.timesig_tics = st->ev.timesig_tics * newunit / oldunit;
-			seqptr_evput(&sp, &ev);
+			seqptr_evput(sp, &ev);
 			break;
 		default:
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 			break;
 		}
 	}
 	statelist_done(&slist);
-	seqptr_done(&sp);
+	seqptr_del(sp);
 }
 
 /*
  * transpose the given track
  */
 void
-track_transpose(struct track *src, unsigned start, unsigned len, int halftones) {
+track_transpose(struct track *src, unsigned start, unsigned len, 
+    struct evspec *es, int halftones)
+{
 	unsigned delta, tic;
 	struct track qt;
-	struct seqptr sp, qp;
+	struct seqptr *sp, *qp;
 	struct state *st;
 	struct statelist slist;
 	struct ev ev;
 
 	track_init(&qt);
-	seqptr_init(&sp, src);
-	seqptr_init(&qp, &qt);
+	sp = seqptr_new(src);
+	qp = seqptr_new(&qt);
 
 	/*
 	 * go to t start position and untag all frames
 	 * (tagged = will be transposed)
 	 */
-	(void)seqptr_skip(&sp, start);
-	statelist_dup(&slist, &sp.statelist);
+	(void)seqptr_skip(sp, start);
+	statelist_dup(&slist, &sp->statelist);
 	for (st = slist.first; st != NULL; st = st->next) {
 		st->tag = 0;
 	}
-	seqptr_seek(&qp, start);
+	seqptr_seek(qp, start);
 	tic = start;
 
 	/*
 	 * go ahead and copy all events to transpose during 'len' tics,
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, len, &slist);
-		seqptr_ticput(&sp, delta);
-		seqptr_ticput(&qp, delta);
+		delta = seqptr_ticdel(sp, len, &slist);
+		seqptr_ticput(sp, delta);
+		seqptr_ticput(qp, delta);
 		tic += delta;
 		if (tic >= start + len)
-			break;		
-		st = seqptr_evdel(&sp, &slist);
+			break;
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST) {
-			st->tag = EV_ISNOTE(&st->ev) ? 1 : 0;
+			if (EV_ISNOTE(&st->ev) && state_inspec(st, es))
+				st->tag = 1;
+			else
+				st->tag = 0;
 		}
 		if (st->tag) {
 			ev = st->ev;
-			ev.note_num += halftones;
+			ev.note_num += (128 + halftones);
 			ev.note_num &= 0x7f;
-			seqptr_evput(&qp, &ev);
+			seqptr_evput(qp, &ev);
 		} else {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
-	}	    
+	}
 
 	/*
 	 * finish transposed (tagged) frames
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, ~0U, &slist);
-		seqptr_ticput(&sp, delta);
-		seqptr_ticput(&qp, delta);
-		st = seqptr_evdel(&sp, &slist);
+		delta = seqptr_ticdel(sp, ~0U, &slist);
+		seqptr_ticput(sp, delta);
+		seqptr_ticput(qp, delta);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST)
 			st->tag = 0;
 		if (st->tag) {
 			ev = st->ev;
-			ev.note_num += halftones;
+			ev.note_num += (128 + halftones);
 			ev.note_num &= 0x7f;
-			seqptr_evput(&qp, &ev);
+			seqptr_evput(qp, &ev);
 		} else {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 	}
 	track_merge(src, &qt);
 	statelist_done(&slist);
-	seqptr_done(&sp);
-	seqptr_done(&qp);
+	seqptr_del(sp);
+	seqptr_del(qp);
 	track_done(&qt);
 }
 
@@ -1098,13 +1145,14 @@ track_transpose(struct track *src, unsigned start, unsigned len, int halftones)
  * check (and fix) the given track for inconsistencies
  */
 void
-track_check(struct track *src) {
-	struct seqptr sp;
+track_check(struct track *src)
+{
+	struct seqptr *sp;
 	struct state *dst, *st, *stnext;
 	struct statelist slist;
 	unsigned delta;
 
-	seqptr_init(&sp, src);
+	sp = seqptr_new(src);
 	statelist_init(&slist);
 
 	/*
@@ -1112,10 +1160,10 @@ track_check(struct track *src) {
 	 * see statelist_update() for definition of bogus
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, ~0U, &slist);
-		seqptr_ticput(&sp, delta);
+		delta = seqptr_ticdel(sp, ~0U, &slist);
+		seqptr_ticput(sp, delta);
 
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL) {
 			break;
 		}
@@ -1138,9 +1186,9 @@ track_check(struct track *src) {
 			/*
 			 * dont duplicate events
 			 */
-			dst = statelist_lookup(&sp.statelist, &st->ev);
+			dst = statelist_lookup(&sp->statelist, &st->ev);
 			if (dst == NULL || !state_eq(dst, &st->ev)) {
-				seqptr_evput(&sp, &st->ev);
+				seqptr_evput(sp, &st->ev);
 			} else {
 				dbg_puts("track_check: ");
 				ev_dbg(&st->ev);
@@ -1150,15 +1198,15 @@ track_check(struct track *src) {
 	}
 
 	/*
-	 * undo (erase) all unterminated frames 
+	 * undo (erase) all unterminated frames
 	 */
-	for (st = sp.statelist.first; st != NULL; st = stnext) {
+	for (st = sp->statelist.first; st != NULL; st = stnext) {
 		stnext = st->next;
 		if (!(st->phase & EV_PHASE_LAST)) {
 			dbg_puts("track_check: ");
 			ev_dbg(&st->ev);
 			dbg_puts(": unterminated\n");
-			(void)seqptr_rmprev(&sp, st);
+			(void)seqptr_rmprev(sp, st);
 		}
 	}
 
@@ -1169,20 +1217,21 @@ track_check(struct track *src) {
 	 */
 	statelist_empty(&slist);
 	statelist_done(&slist);
-	seqptr_done(&sp);
+	seqptr_del(sp);
 }
 
 /*
  * get the current tempo (at the current position)
  */
 struct state *
-seqptr_getsign(struct seqptr *sp, unsigned *bpm, unsigned *tpb) {
+seqptr_getsign(struct seqptr *sp, unsigned *bpm, unsigned *tpb)
+{
 	struct ev ev;
 	struct state *st;
 
 	ev.cmd = EV_TIMESIG;
 	st = statelist_lookup(&sp->statelist, &ev);
-	if (bpm) 
+	if (bpm)
 		*bpm = (st == NULL) ? DEFAULT_BPM : st->ev.timesig_beats;
 	if (tpb)
 		*tpb = (st == NULL) ? DEFAULT_TPB : st->ev.timesig_tics;
@@ -1193,7 +1242,8 @@ seqptr_getsign(struct seqptr *sp, unsigned *bpm, unsigned *tpb) {
  * get the current tempo (at the current position)
  */
 struct state *
-seqptr_gettempo(struct seqptr *sp, unsigned long *usec24) {
+seqptr_gettempo(struct seqptr *sp, unsigned long *usec24)
+{
 	struct ev ev;
 	struct state *st;
 
@@ -1211,9 +1261,10 @@ seqptr_gettempo(struct seqptr *sp, unsigned long *usec24) {
  * (only on premature end-of-track)
  */
 unsigned
-seqptr_skipmeasure(struct seqptr *sp, unsigned meas) {
+seqptr_skipmeasure(struct seqptr *sp, unsigned meas)
+{
 	unsigned m, bpm, tpb, tics_per_meas, delta;
-	
+
 	for (m = 0; m < meas; m++) {
 		while (seqptr_evget(sp)) {
 			/* nothing */
@@ -1232,14 +1283,15 @@ seqptr_skipmeasure(struct seqptr *sp, unsigned meas) {
  * meta-events from the given track
  */
 unsigned
-track_findmeasure(struct track *t, unsigned m) {
-	struct seqptr sp;
+track_findmeasure(struct track *t, unsigned m)
+{
+	struct seqptr *sp;
 	unsigned tic;
 
-	seqptr_init(&sp, t);
-	tic  = seqptr_skipmeasure(&sp, m);
-	tic += sp.tic;
-	seqptr_done(&sp);
+	sp = seqptr_new(t);
+	tic  = seqptr_skipmeasure(sp, m);
+	tic += sp->tic;
+	seqptr_del(sp);
 
 #ifdef FRAME_DEBUG
 	dbg_puts("track_findmeasure: ");
@@ -1257,36 +1309,38 @@ track_findmeasure(struct track *t, unsigned m) {
  * corresponding to the given measure number
  */
 void
-track_timeinfo(struct track *t, unsigned meas, unsigned *abs, 
-    unsigned long *usec24, unsigned *bpm, unsigned *tpb) {
-	struct seqptr sp;
+track_timeinfo(struct track *t, unsigned meas, unsigned *abs,
+    unsigned long *usec24, unsigned *bpm, unsigned *tpb)
+{
+	struct seqptr *sp;
 	unsigned tic;
 
-	seqptr_init(&sp, t);
-	tic  = seqptr_skipmeasure(&sp, meas);
-	tic += sp.tic;
+	sp = seqptr_new(t);
+	tic  = seqptr_skipmeasure(sp, meas);
+	tic += sp->tic;
 
 	/*
 	 * move to the last event, so all meta events enter the
 	 * state list
 	 */
-	while (seqptr_evget(&sp)) {
+	while (seqptr_evget(sp)) {
 		/* nothing */
 	}
 	if (abs) {
 		*abs = tic;
 	}
-	seqptr_getsign(&sp, bpm, tpb);
-	seqptr_gettempo(&sp, usec24);
-	seqptr_done(&sp);
+	seqptr_getsign(sp, bpm, tpb);
+	seqptr_gettempo(sp, usec24);
+	seqptr_del(sp);
 }
 
 /*
  * go to the given measure and set the tempo
  */
 void
-track_settempo(struct track *t, unsigned measure, unsigned tempo) {
-	struct seqptr sp;
+track_settempo(struct track *t, unsigned measure, unsigned tempo)
+{
+	struct seqptr *sp;
 	struct state *st;
 	struct statelist slist;
 	struct ev ev;
@@ -1297,52 +1351,52 @@ track_settempo(struct track *t, unsigned measure, unsigned tempo) {
 	/*
 	 * go to the requested position, insert blank if necessary
 	 */
-	seqptr_init(&sp, t);
-	tic = seqptr_skipmeasure(&sp, measure);
+	sp = seqptr_new(t);
+	tic = seqptr_skipmeasure(sp, measure);
 	if (tic) {
-		seqptr_ticput(&sp, tic);
+		seqptr_ticput(sp, tic);
 	}
-	statelist_dup(&slist, &sp.statelist);
+	statelist_dup(&slist, &sp->statelist);
 
 	/*
 	 * remove tempo events at the current tic
 	 */
 	for (;;) {
-		st = seqptr_evdel(&sp, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->ev.cmd != EV_TEMPO)
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 	}
 
 	/*
 	 * if needed, insert a new tempo event
 	 */
-	seqptr_getsign(&sp, &bpm, &tpb);
+	seqptr_getsign(sp, &bpm, &tpb);
 	usec24 = TEMPO_TO_USEC24(tempo, tpb);
-	seqptr_gettempo(&sp, &old_usec24);
+	seqptr_gettempo(sp, &old_usec24);
 	if (usec24 != old_usec24) {
 		ev.cmd = EV_TEMPO;
 		ev.tempo_usec24 = usec24;
-		seqptr_evput(&sp, &ev);
+		seqptr_evput(sp, &ev);
 	}
 
 	/*
 	 * move next events, skipping duplicate tempos
 	 */
 	for (;;) {
-		delta = seqptr_ticdel(&sp, ~0U, &slist);
-		seqptr_ticput(&sp, delta);
-		st = seqptr_evdel(&sp, &slist);
+		delta = seqptr_ticdel(sp, ~0U, &slist);
+		seqptr_ticput(sp, delta);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
-		if (st->ev.cmd != EV_TEMPO || 
+		if (st->ev.cmd != EV_TEMPO ||
 		    st->ev.tempo_usec24 != usec24) {
 			usec24 = st->ev.tempo_usec24;
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 	}
-	seqptr_done(&sp);
+	seqptr_del(sp);
 	statelist_done(&slist);
 }
 
@@ -1351,8 +1405,9 @@ track_settempo(struct track *t, unsigned measure, unsigned tempo) {
  * event, then replace it.
  */
 void
-track_confev(struct track *src, struct ev *ev) {
-	struct seqptr sp;
+track_confev(struct track *src, struct ev *ev)
+{
+	struct seqptr *sp;
 	struct statelist slist;
 	struct state *st;
 
@@ -1364,59 +1419,189 @@ track_confev(struct track *src, struct ev *ev) {
 		return;
 	}
 
-	seqptr_init(&sp, src);
+	sp = seqptr_new(src);
 	statelist_init(&slist);
-       
+
 	/*
 	 * rewrite the track, removing frames matching the event
 	 */
 	for (;;) {
-		(void)seqptr_ticdel(&sp, ~0U, &slist);
-		st = seqptr_evdel(&sp, &slist);
+		(void)seqptr_ticdel(sp, ~0U, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST) {
 			st->tag = state_match(st, ev) ? 0 : 1;
 		}
 		if (st->tag) {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 
 	}
-	seqptr_evput(&sp, ev);
+	seqptr_evput(sp, ev);
 	statelist_done(&slist);
-	seqptr_done(&sp);
+	seqptr_del(sp);
 }
 
 /*
  * remove a set of events from the "config" track
  */
 void
-track_unconfev(struct track *src, struct evspec *es) {
+track_unconfev(struct track *src, struct evspec *es)
+{
 	struct statelist slist;
-	struct seqptr sp;
+	struct seqptr *sp;
 	struct state *st;
 
-	seqptr_init(&sp, src);
+	sp = seqptr_new(src);
 	statelist_init(&slist);
-       
+
 	/*
 	 * rewrite the track, removing frames matching the spec
 	 */
 	for (;;) {
-		(void)seqptr_ticdel(&sp, ~0U, &slist);
-		st = seqptr_evdel(&sp, &slist);
+		(void)seqptr_ticdel(sp, ~0U, &slist);
+		st = seqptr_evdel(sp, &slist);
 		if (st == NULL)
 			break;
 		if (st->phase & EV_PHASE_FIRST) {
 			st->tag = state_inspec(st, es) ? 0 : 1;
 		}
 		if (st->tag) {
-			seqptr_evput(&sp, &st->ev);
+			seqptr_evput(sp, &st->ev);
 		}
 
 	}
 	statelist_done(&slist);
-	seqptr_done(&sp);
+	seqptr_del(sp);
 }
 
+/*
+ * insert the given amount of blank space at the given position
+ */
+void
+track_ins(struct track *t, unsigned stic, unsigned len)
+{
+	struct track t1, t2;
+
+	track_init(&t1);
+	track_init(&t2);
+	track_move(t, 0 ,  stic, NULL, &t1, 1, 1);
+	track_move(t, stic, ~0U, NULL, &t2, 1, 1);
+	track_shift(&t2, stic + len);
+	track_clear(t);
+	track_merge(t, &t1);
+	if (!track_isempty(&t2)) {
+		track_merge(t, &t2);
+	}
+	track_done(&t1);
+	track_done(&t2);
+}
+
+/*
+ * cut the given portion of the track
+ */
+void
+track_cut(struct track *t, unsigned stic, unsigned len)
+{
+	struct track t1, t2;
+
+	track_init(&t1);
+	track_init(&t2);
+	track_move(t, 0,	 stic, NULL, &t1, 1, 1);
+	track_move(t, stic + len, ~0U, NULL, &t2, 1, 1);
+	track_shift(&t2, stic);
+	track_clear(t);
+	track_merge(t, &t1);
+	if (!track_isempty(&t2)) {
+		track_merge(t, &t2);
+	}
+	track_done(&t1);
+	track_done(&t2);
+}
+
+/*
+ * map current selection to the given evspec
+ */
+void
+track_evmap(struct track *src, unsigned start, unsigned len, 
+    struct evspec *es, struct evspec *from, struct evspec *to)
+{
+	unsigned delta, tic;
+	struct track qt;
+	struct seqptr *sp, *qp;
+	struct state *st;
+	struct statelist slist;
+	struct ev ev;
+
+	if (!evspec_isamap(from, to))
+		return;
+
+	track_init(&qt);
+	sp = seqptr_new(src);
+	qp = seqptr_new(&qt);
+
+	/*
+	 * go to t start position and untag all frames
+	 * (tagged = will be mapped)
+	 */
+	(void)seqptr_skip(sp, start);
+	statelist_dup(&slist, &sp->statelist);
+	for (st = slist.first; st != NULL; st = st->next) {
+		st->tag = 0;
+	}
+	seqptr_seek(qp, start);
+	tic = start;
+
+	/*
+	 * go ahead and copy all events to map during 'len' tics,
+	 */
+	for (;;) {
+		delta = seqptr_ticdel(sp, len, &slist);
+		seqptr_ticput(sp, delta);
+		seqptr_ticput(qp, delta);
+		tic += delta;
+		if (tic >= start + len)
+			break;
+		st = seqptr_evdel(sp, &slist);
+		if (st == NULL)
+			break;
+		if (st->phase & EV_PHASE_FIRST) {
+			if (state_inspec(st, es) && state_inspec(st, from))
+				st->tag = 1;
+			else
+				st->tag = 0;
+		}
+		if (st->tag) {
+			ev_map(&st->ev, from, to, &ev);
+			seqptr_evput(qp, &ev);
+		} else {
+			seqptr_evput(sp, &st->ev);
+		}
+	}
+
+	/*
+	 * finish mapped (tagged) frames
+	 */
+	for (;;) {
+		delta = seqptr_ticdel(sp, ~0U, &slist);
+		seqptr_ticput(sp, delta);
+		seqptr_ticput(qp, delta);
+		st = seqptr_evdel(sp, &slist);
+		if (st == NULL)
+			break;
+		if (st->phase & EV_PHASE_FIRST)
+			st->tag = 0;
+		if (st->tag) {
+			ev_map(&st->ev, from, to, &ev);
+			seqptr_evput(qp, &ev);
+		} else {
+			seqptr_evput(sp, &st->ev);
+		}
+	}
+	track_merge(src, &qt);
+	statelist_done(&slist);
+	seqptr_del(sp);
+	seqptr_del(qp);
+	track_done(&qt);
+}
