@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -36,13 +36,13 @@
 #define TOK_MAXLEN	STRING_MAXLEN
 
 enum SYM_ID {
-	TOK_EOF = 0, TOK_ASSIGN, 
+	TOK_EOF = 0, TOK_ASSIGN,
 	TOK_PLUS, TOK_MINUS, TOK_STAR, TOK_SLASH, TOK_PCT,
 	TOK_LSHIFT, TOK_RSHIFT, TOK_BITAND, TOK_BITOR, TOK_BITXOR, TOK_TILDE,
-	TOK_EQ, TOK_NEQ, TOK_GE, TOK_GT, TOK_LE, TOK_LT, 
+	TOK_EQ, TOK_NEQ, TOK_GE, TOK_GT, TOK_LE, TOK_LT,
 	TOK_EXCLAM, TOK_AND, TOK_OR,
 	TOK_LPAR, TOK_RPAR, TOK_LBRACE, TOK_RBRACE, TOK_LBRACKET, TOK_RBRACKET,
-	TOK_COMMA, TOK_DOT, TOK_SEMICOLON, TOK_COLON, 
+	TOK_COMMA, TOK_DOT, TOK_SEMICOLON, TOK_COLON, TOK_RANGE,
 	TOK_AT, TOK_DOLLAR, TOK_ENDLINE,
 	/* keywords */
 	TOK_IF, TOK_ELSE, TOK_WHILE, TOK_DO, TOK_FOR, TOK_IN,
@@ -59,7 +59,7 @@ struct tokdef {
 struct lex {
 	unsigned id;
 	char strval[TOK_MAXLEN + 1];
-	unsigned long longval;	
+	unsigned long longval;
 	struct textin *in;		/* input file */
 	int lookchar;			/* used by ungetchar */
 	unsigned line, col;		/* for error reporting */
@@ -70,10 +70,10 @@ void     lex_done(struct lex *);
 unsigned lex_scan(struct lex *);
 void	 lex_dbg(struct lex *);
 
-unsigned lex_getchar(struct lex *o, int *c);
-void	 lex_ungetchar(struct lex *o, int c);
-void	 lex_err(struct lex *o, char *msg);
-void	 lex_recover(struct lex *o, char *msg);
-unsigned lex_str2long(struct lex *o, unsigned base);
+unsigned lex_getchar(struct lex *, int *);
+void	 lex_ungetchar(struct lex *, int);
+void	 lex_err(struct lex *, char *);
+void	 lex_recover(struct lex *, char *);
+unsigned lex_str2long(struct lex *, unsigned);
 
 #endif /* MIDISH_LEX_H */
