@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -29,28 +29,47 @@
  */
 
 #include <stdio.h>
+#include <unistd.h>
+
 #include "dbg.h"
 #include "str.h"
-
 #include "cons.h"
 #include "ev.h"
 #include "mux.h"
 #include "track.h"
+#include "frame.h"
 #include "song.h"
 #include "user.h"
 #include "filt.h"
 #include "mididev.h"
-#include "default.h"
+#include "defs.h"
 #include "sysex.h"
 #include "textio.h"
 
-
 int
-main(int argc, char **argv) {
+main(int argc, char **argv)
+{
+	int ch;
 	unsigned exitcode;
-	
-	if (!user_getopts(&argc, &argv)) {
-		return 1;
+
+	while ((ch = getopt(argc, argv, "bv")) != -1) {
+		switch (ch) {
+		case 'b':
+			user_flag_batch = 1;
+			break;
+		case 'v':
+			user_flag_verb = 1;
+			break;
+		default:
+			goto err;
+		}
+	}
+	argc -= optind;
+	argv += optind;
+	if (argc >= 1) {
+	err:
+		fputs("usage: midish [-bv]\n", stderr);
+		return 0;
 	}
 
 	cons_init();
@@ -60,11 +79,13 @@ main(int argc, char **argv) {
 	state_pool_init(DEFAULT_MAXNSTATES);
 	chunk_pool_init(DEFAULT_MAXNCHUNKS);
 	sysex_pool_init(DEFAULT_MAXNSYSEXS);
+	seqptr_pool_init(DEFAULT_MAXNSEQPTRS);
 	mididev_listinit();
-		
+
 	exitcode = user_mainloop();
-	
+
 	mididev_listdone();
+	seqptr_pool_done();
 	sysex_pool_done();
 	chunk_pool_done();
 	state_pool_done();
@@ -72,7 +93,7 @@ main(int argc, char **argv) {
 	evctl_done();
 	textio_done();
 	cons_done();
-	
+
 	mem_stats();
 	return exitcode ? 0 : 1;
 }
