@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -33,11 +33,11 @@
  *	- midi input and output
  *	- internal external/timer
  *
- * the time unit is the 24th of microsecond (thus the tempo is stored
- * with the same accurancy as in standard midi files).
+ * the clock unit is the 24th of microsecond (thus the tempo is stored
+ * with the same accuracy as in standard midi files).
  *
  * the timer has the following states:
- * STOP -> STARTWAIT -> START -> FIRST_TIC -> NEXT_TIC -> STOPWAIT -> STOP
+ * STOP -> STARTWAIT -> START -> FIRST_TIC -> NEXT_TIC -> STOP
  *
  * STARTWAIT:
  *
@@ -51,7 +51,7 @@
  *	we just received the "start" MIDI event, so we wait for the
  *	first "tick" MIDI event; once it's received we switch to the
  *	next state (FIRST_TIC). If the internal clock source is used
- *	we wait MUX_START_DELAT (0.1 second) and we switch to the next
+ *	we wait MUX_START_DELAY (0.1 second) and we switch to the next
  *	state.
  *
  * FIRST_TIC:
@@ -65,13 +65,6 @@
  *	we received another "tick" event, move the music one
  *	step forward.
  *
- * STOPWAIT:
- *
- *	the music is over, so the upper layer puts this module in the
- *	STOPWAIT state. So we just wait for the "stop" MIDI event;
- *	that's necessary because other MIDI sequencers may not have
- *	finished. 
- *
  * STOP:
  *
  *	nothing to do, ignore any MIDI sync events.
@@ -80,40 +73,47 @@
 
 #include "dbg.h"
 #include "ev.h"
-
-#include "default.h"
-#include "mdep.h"
+#include "cons.h"
+#include "defs.h"
 #include "mux.h"
-#include "rmidi.h"
+#include "mididev.h"
 #include "sysex.h"
 #include "timo.h"
 #include "state.h"
 #include "conv.h"
 
-/* 
- * MUX_START_DELAY: 
+#include "norm.h"
+#include "mixout.h"
+
+/*
+ * MUX_START_DELAY:
  *
  * delay between the START event and the first TIC in 24ths of a micro
  * second, here we use 1 tic at 30bpm
  */
-#define MUX_START_DELAY	  (2000000UL)	
+#define MUX_START_DELAY	  (24000000UL / 3)
 
+unsigned mux_isopen = 0;
 unsigned mux_debug = 0;
 unsigned mux_ticrate;
 unsigned long mux_ticlength, mux_curpos, mux_nextpos;
 unsigned mux_curtic;
-unsigned mux_phase;
-struct muxops *mux_ops;
+unsigned mux_phase, mux_reqphase;
 void *mux_addr;
 
+
+#ifdef MUX_PROF
+struct prof mux_prof;
+#endif
+
 struct statelist mux_istate, mux_ostate;
 
+void mux_sendstop(void);
 /*
  * the following are defined in mdep.c
  */
 void mux_mdep_open(void);
 void mux_mdep_close(void);
-void mux_mdep_run(void);
 
 void mux_dbgphase(unsigned phase);
 void mux_chgphase(unsigned phase);
@@ -122,66 +122,82 @@ void mux_chgphase(unsigned phase);
  * initialize all structures and open all midi devices
  */
 void
-mux_open(struct muxops *ops, void *addr) {
+mux_open(void)
+{
 	struct mididev *i;
 
+	timo_init();
 	statelist_init(&mux_istate);
 	statelist_init(&mux_ostate);
-	
-	/* 
+	mixout_start();
+	norm_start();
+
+	/*
 	 * default tempo is 120 beats per minutes with 24 tics per
 	 * beat (time unit = 24th of microsecond)
 	 */
 	mux_ticlength = TEMPO_TO_USEC24(DEFAULT_TEMPO, DEFAULT_TPB);
-	
-	/* 
+
+	/*
 	 * default tics per second = 96
 	 */
 	mux_ticrate = DEFAULT_TPU;
-	
+
 	/*
-	 * reset tic counters of devices 
+	 * reset tic counters of devices
 	 */
-	mux_mdep_open();
+	mux_isopen = 1;
 	for (i = mididev_list; i != NULL; i = i->next) {
 		i->ticdelta = i->ticrate;
 		i->isensto = 0;
 		i->osensto = MIDIDEV_OSENSTO;
-		rmidi_open(RMIDI(i));
+		mididev_open(i);
 	}
+	mux_mdep_open();
 
 	mux_curpos = 0;
 	mux_nextpos = 0;
+	mux_reqphase = MUX_STOP;
 	mux_phase = MUX_STOP;
-	mux_ops = ops;
-	mux_addr = addr;
-	timo_init();
+#ifdef MUX_PROF
+	prof_reset(&mux_prof, "mux/ms");
+#endif
+	dbg_sync = 1;
 }
 
 /*
  * release all structures and close midi devices
  */
 void
-mux_close(void) {
+mux_close(void)
+{
 	struct mididev *i;
 
+	dbg_sync = 1;
+#ifdef MUX_PROF
+	prof_dbg(&mux_prof);
+#endif
+	norm_stop();
+	mixout_stop();
 	mux_flush();
 	for (i = mididev_list; i != NULL; i = i->next) {
-		if (RMIDI(i)->isysex) {
-			dbg_puts("lost incomplete sysex\n");
-			sysex_del(RMIDI(i)->isysex);
+		if (i->isysex) {
+			cons_err("lost incomplete sysex");
+			sysex_del(i->isysex);
 		}
-		rmidi_close(RMIDI(i));
+		mididev_close(i);
 	}
 	mux_mdep_close();
-	timo_done();
+	mux_isopen = 0;
 	statelist_done(&mux_ostate);
 	statelist_done(&mux_istate);
+	timo_done();
 }
 
 #ifdef MUX_DEBUG
 void
-mux_dbgphase(unsigned phase) {
+mux_dbgphase(unsigned phase)
+{
 	switch(phase) {
 	case MUX_STARTWAIT:
 		dbg_puts("STARTWAIT");
@@ -195,9 +211,6 @@ mux_dbgphase(unsigned phase) {
 	case MUX_NEXT:
 		dbg_puts("NEXT");
 		break;
-	case MUX_STOPWAIT:
-		dbg_puts("STOPWAIT");
-		break;
 	case MUX_STOP:
 		dbg_puts("STOP");
 		break;
@@ -212,7 +225,8 @@ mux_dbgphase(unsigned phase) {
  * change the current phase
  */
 void
-mux_chgphase(unsigned phase) {
+mux_chgphase(unsigned phase)
+{
 #ifdef MUX_DEBUG
 	dbg_puts("mux_phase: ");
 	mux_dbgphase(mux_phase);
@@ -228,13 +242,14 @@ mux_chgphase(unsigned phase) {
  * is only sent if the device tic_per_unit permits it.
  */
 void
-mux_sendtic(void) {
+mux_sendtic(void)
+{
 	struct mididev *i;
 
 	for (i = mididev_list; i != NULL; i = i->next) {
-		if (i->sendrt && i != mididev_master) {
+		if (i->sendclk && i != mididev_clksrc) {
 			while (i->ticdelta >= mux_ticrate) {
-				rmidi_puttic(RMIDI(i));
+				mididev_puttic(i);
 				i->ticdelta -= mux_ticrate;
 			}
 			i->ticdelta += i->ticrate;
@@ -246,19 +261,20 @@ mux_sendtic(void) {
  * similar to sendtic, but sends a START event
  */
 void
-mux_sendstart(void) {
+mux_sendstart(void)
+{
 	struct mididev *i;
 
 	for (i = mididev_list; i != NULL; i = i->next) {
-		if (i->sendrt && i != mididev_master) {
+		if (i->sendclk && i != mididev_clksrc) {
 			i->ticdelta = i->ticrate;
 			/*
 			 * send a spirious tick just before the start
 			 * event in order to notify that we are the
 			 * master
 			 */
-			rmidi_puttic(RMIDI(i));
-			rmidi_putstart(RMIDI(i));
+			mididev_puttic(i);
+			mididev_putstart(i);
 		}
 	}
 }
@@ -267,12 +283,13 @@ mux_sendstart(void) {
  * similar to sendtic, but send a STOP event
  */
 void
-mux_sendstop(void) {
+mux_sendstop(void)
+{
 	struct mididev *i;
 
 	for (i = mididev_list; i != NULL; i = i->next) {
-		if (i->sendrt && i != mididev_master) {
-			rmidi_putstop(RMIDI(i));
+		if (i->sendclk && i != mididev_clksrc) {
+			mididev_putstop(i);
 		}
 	}
 }
@@ -282,32 +299,39 @@ mux_sendstop(void) {
  * other routines should be used to send events
  */
 void
-mux_putev(struct ev *ev) {
+mux_putev(struct ev *ev)
+{
 	unsigned unit;
 	struct mididev *dev;
 	struct ev rev[CONV_NUMREV];
 	unsigned i, nev;
-	
+
 #ifdef MUX_DEBUG
-	dbg_puts("mux_putev: ");
-	ev_dbg(ev);
-	dbg_puts("\n");
+	if (mux_debug) {
+		dbg_puts("mux_putev: ");
+		ev_dbg(ev);
+		dbg_puts("\n");
+	}
 #endif
 
 	if (!EV_ISVOICE(ev)) {
-		dbg_puts("mux_putev: only voice events allowed\n");
+		dbg_puts("mux_putev: ");
+		ev_dbg(ev);
+		dbg_puts(": only voice events allowed\n");
 		dbg_panic();
 	}
 	unit = ev->dev;
 	if (unit >= DEFAULT_MAXNDEVS) {
-		dbg_puts("mux_putev: bogus unit number\n");
+		dbg_puts("mux_putev: ");
+		ev_dbg(ev);
+		dbg_puts(": bogus unit number\n");
 		dbg_panic();
 	}
 	dev = mididev_byunit[unit];
 	if (dev != NULL) {
 		nev = conv_unpackev(&mux_ostate, dev->oxctlset, ev, rev);
 		for (i = 0; i < nev; i++) {
-			rmidi_putev(RMIDI(dev), &rev[i]);
+			mididev_putev(dev, &rev[i]);
 		}
 	}
 }
@@ -317,7 +341,8 @@ mux_putev(struct ev *ev) {
  * sysex messages
  */
 void
-mux_sendraw(unsigned unit, unsigned char *buf, unsigned len) {
+mux_sendraw(unsigned unit, unsigned char *buf, unsigned len)
+{
 	struct mididev *dev;
 	if (unit >= DEFAULT_MAXNDEVS) {
 		return;
@@ -329,107 +354,193 @@ mux_sendraw(unsigned unit, unsigned char *buf, unsigned len) {
 	if (dev == NULL) {
 		return;
 	}
-	rmidi_sendraw(RMIDI(dev), buf, len);
+	mididev_sendraw(dev, buf, len);
 }
 
 /*
- * call-back called every time the clock changed, the argument
+ * called when MTC timer starts (full frame message).
+ */
+void
+mux_mtcstart(unsigned mtcpos)
+{
+	/*
+	 * not using MTC, do nothing
+	 */
+	if (mididev_clksrc)
+		return;
+
+	/*
+	 * if already started, trigger a MTC stop to enter
+	 * a state in which we can start
+	 */
+	if (mux_phase >= MUX_START && mux_phase <= MUX_NEXT) {
+		if (mux_debug)
+			dbg_puts("mux_mtcstart: triggered stop\n");
+		mux_mtcstop();
+	}
+
+	/*
+	 * check if we're trying to start, if not just return
+	 */
+	if (mux_phase == MUX_STOP) {
+		if (mux_debug)
+			dbg_puts("mux_mtcstart: ignored mtc start (stopped)\n");
+		return;
+	}
+
+	/*
+	 * ignore position change if we're not using MTC because
+	 * it's already set (e.g., internally generated MTC start)
+	 */
+	if (mididev_mtcsrc) {
+		mux_nextpos = mux_ticlength;
+		mux_curpos = song_gotocb(usong, mtcpos);
+		if (mux_curpos >= mux_ticlength)
+			dbg_puts("mux_mtcstart: offset larger than 1 tick\n");
+	}
+
+	/*
+	 * generate clock start
+	 */
+	if (mux_debug)
+		dbg_puts("mux_mtcstart: generated clk start\n");
+	mux_sendstart();
+	mux_startcb();
+	mux_flush();
+}
+
+/*
+ * called periodically by the MTC timer
+ */
+void
+mux_mtctick(unsigned delta)
+{
+	/*
+	 * if using external clock, ignore MTC
+	 */
+	if (mididev_clksrc)
+		return;
+
+	mux_curpos += delta;
+
+	while (mux_curpos >= mux_nextpos) {
+		mux_curpos -= mux_nextpos;
+		mux_nextpos = mux_ticlength;
+		mux_sendtic();
+		mux_ticcb();
+		mux_flush();
+	}
+}
+
+/*
+ * called when the MTC timer stops
+ */
+void
+mux_mtcstop(void)
+{
+	/*
+	 * if using external clock, ignore MTC
+	 */
+	if (mididev_clksrc)
+		return;
+
+	if (mux_phase >= MUX_START) {
+		if (mux_debug)
+			dbg_puts("mux_mtcstop: generated stop\n");
+		mux_sendstop();
+		mux_stopcb();
+		mux_flush();
+	}
+}
+
+/*
+ * call-back called every time the clock changes, the argument
  * contains the number of 24th of seconds elapsed since the last call
  */
 void
-mux_timercb(unsigned long delta) {
+mux_timercb(unsigned long delta)
+{
 	struct mididev *dev;
-	mux_curpos += delta;
-	
+
+#ifdef MUX_PROF
+	prof_val(&mux_prof, delta / (24 * 10));
+#endif
+
 	/*
 	 * run expired timeouts
 	 */
 	timo_update(delta);
 
 	/*
-	 * handle active sensing
+	 * handle timeouts not using the timo.c interface
+	 * XXX: convert this to timo_xxx() routines
 	 */
 	for (dev = mididev_list; dev != NULL; dev = dev->next) {
 		if (dev->isensto) {
 			if (dev->isensto <= delta) {
 				dev->isensto = 0;
-				dbg_putu(dev->unit);
-				dbg_puts(": sensing timeout, disabled\n");
+				cons_erru(dev->unit, "sensing timeout, disabled");
 			} else {
 				dev->isensto -= delta;
 			}
 		}
 		if (dev->osensto) {
 			if (dev->osensto <= delta) {
-				rmidi_putack(RMIDI(dev));
-				rmidi_flush(RMIDI(dev));
+				mididev_putack(dev);
+				mididev_flush(dev);
 				dev->osensto = MIDIDEV_OSENSTO;
 			} else {
 				dev->osensto -= delta;
 			}
 		}
+		if (dev->imtc.timo) {
+			if (dev->imtc.timo <= delta) {
+				dev->imtc.timo = 0;
+				mtc_timo(&dev->imtc);
+			} else {
+				dev->imtc.timo -= delta;
+			}
+		}
 	}
-	
-	/*
-	 * update clocks, when necessary
-	 */
-	if (!mididev_master) {	
-		/* 
-		 * internal clock source (no master) 
-		 */
-		if (mux_phase == MUX_STARTWAIT) {
-			mux_chgphase(MUX_START);
-			mux_sendstart();
-			mux_curpos = 0;
-			mux_nextpos = MUX_START_DELAY;
-			if (mux_debug) {
-				dbg_puts("mux_timercb: generated start\n");
-			}
-			mux_flush();
-		}
 
-		if (mux_phase == MUX_STOPWAIT) {
-			mux_chgphase(MUX_STOP);
-			if (mux_debug) {
-				dbg_puts("mux_timercb: generated stop\n");
+	/*
+	 * if there's no ext MTC source, then generate one internally
+	 * using the current sequencer state as hints
+	 */
+	if (!mididev_mtcsrc && !mididev_clksrc) {
+		switch (mux_phase) {
+		case MUX_STARTWAIT:
+			dbg_puts("mux_timercb: startwait: bad state\n");
+			dbg_panic();
+			break;
+		case MUX_START:
+			mux_curpos += delta;
+			if (mux_curpos >= mux_nextpos) {
+				mux_curpos = 0;
+				mux_nextpos = 0;
+				mux_mtctick(0);
 			}
-			mux_ops->stop(mux_addr);
-			mux_sendstop();
-			mux_flush();
-		}
-		
-		while (mux_curpos >= mux_nextpos) {
-			mux_curpos -= mux_nextpos;
-			mux_nextpos = mux_ticlength;
-			if (mux_phase == MUX_FIRST) {
-				mux_chgphase(MUX_NEXT);
-			} else if (mux_phase == MUX_START) {
-				mux_chgphase(MUX_FIRST);
-			}
-			mux_sendtic();
-			if (mux_phase == MUX_NEXT) {
-				mux_curtic++;
-				mux_ops->move(mux_addr);
-			} else if (mux_phase == MUX_FIRST) {
-				mux_curtic = 0;
-				mux_ops->start(mux_addr);
-			}
-			mux_flush();	
+			break;
+		case MUX_FIRST:
+		case MUX_NEXT:
+			mux_mtctick(delta);
+			break;
 		}
 	}
 }
 
 /*
- * called when a MIDI TICK is received from an external device
+ * called when a MIDI TICK is received
  */
 void
-mux_ticcb(unsigned unit) {
-	struct mididev *dev = mididev_byunit[unit];
-
-	if (!mididev_master || dev != mididev_master) {	
-		return;
-	}
-	while (mididev_master->ticdelta >= mididev_master->ticrate) {
+mux_ticcb(void)
+{
+	for (;;) {
+		if (mididev_clksrc != NULL &&
+		    mididev_clksrc->ticdelta < mididev_clksrc->ticrate) {
+			mididev_clksrc->ticdelta += mux_ticrate;
+			break;
+		}
 		if (mux_phase == MUX_FIRST) {
 			mux_chgphase(MUX_NEXT);
 		} else if (mux_phase == MUX_START) {
@@ -437,60 +548,64 @@ mux_ticcb(unsigned unit) {
 		}
 		if (mux_phase == MUX_NEXT) {
 			mux_curtic++;
-			mux_ops->move(mux_addr);
+			song_movecb(usong);
 		} else if (mux_phase == MUX_FIRST) {
 			mux_curtic = 0;
-			mux_ops->start(mux_addr);
+			song_startcb(usong);
 		}
-		/* XXX: where is the flush ?! */
-		mididev_master->ticdelta -= mididev_master->ticrate;
+		if (mididev_clksrc == NULL)
+			break;
+		mididev_clksrc->ticdelta -= mididev_clksrc->ticrate;
 	}
-	mididev_master->ticdelta += mux_ticrate;
 }
 
 /*
  * called when a MIDI START event is received from an external device
  */
 void
-mux_startcb(unsigned unit) {
-	struct mididev *dev = mididev_byunit[unit];
-
-	if (!mididev_master || dev != mididev_master) {	
+mux_startcb(void)
+{
+	if (mux_debug)
+		dbg_puts("mux_startcb: got start event\n");
+	if (mux_phase != MUX_STARTWAIT) {
+		dbg_puts("mux_startcb: ignored MIDI start (not ready)\n");
 		return;
 	}
-	mux_chgphase(MUX_START);
-	if (mux_debug) {
-		dbg_puts("mux_startcb: got start event\n");
+
+	/*
+	 * if the MIDI START event comes from a device
+	 * move to the beginning (we don't support SPP yet)
+	 */
+	if (mididev_clksrc) {
+		mux_curpos = 0;
+		mux_nextpos = mux_ticlength;
+		song_gotocb(usong, 0);
 	}
+	mux_chgphase(MUX_START);
 }
 
 /*
  * called when a MIDI STOP event is received from an external device
  */
 void
-mux_stopcb(unsigned unit) {
-	struct mididev *dev = mididev_byunit[unit];
-
-	if (!mididev_master || dev != mididev_master) {	
-		return;
-	}
-	mux_chgphase(MUX_STOP);
-	if (mux_debug) {
-		dbg_puts("mux_startcb: got stop\n");
-	}
-	mux_ops->stop(mux_addr);
+mux_stopcb(void)
+{
+	if (mux_debug)
+		dbg_puts("mux_stopcb: got stop\n");
+	mux_chgphase(mux_reqphase);
+	song_stopcb(usong);
 }
 
 /*
  * called when a MIDI Active-sensing is received from an external device
  */
 void
-mux_ackcb(unsigned unit) {
+mux_ackcb(unsigned unit)
+{
 	struct mididev *dev = mididev_byunit[unit];
 
 	if (dev->isensto == 0) {
-		dbg_putu(dev->unit);
-		dbg_puts(": sensing enabled\n");
+		cons_erru(dev->unit, "sensing enabled");
 		dev->isensto = MIDIDEV_ISENSTO;
 	}
 }
@@ -499,87 +614,73 @@ mux_ackcb(unsigned unit) {
  * called when a MIDI voice event is received from an external device
  */
 void
-mux_evcb(unsigned unit, struct ev *ev) {
+mux_evcb(unsigned unit, struct ev *ev)
+{
 	struct ev rev;
 	struct mididev *dev = mididev_byunit[ev->dev];
+
 #ifdef MUX_DEBUG
-	dbg_puts("mux_evcb: ");
-	ev_dbg(ev);
-	dbg_puts("\n");
+	if (mux_debug) {
+		dbg_puts("mux_evcb: ");
+		ev_dbg(ev);
+		dbg_puts("\n");
+	}
 #endif
 	if (conv_packev(&mux_istate, dev->ixctlset, ev, &rev)) {
-		mux_ops->ev(mux_addr, &rev);
+		norm_evcb(&rev);
 	}
 }
 
 /*
  * called if an error is detected. currently we send an all note off
  * and all ctls reset
- *
- * XXX: these controllers should be handled by the filter
- *	they should shutdown recorded states following filtering
- *	rules.
  */
 void
-mux_errorcb(unsigned unit) {
-	unsigned i;
-	struct ev ev;
-	
-	/* 
-	 * send all sound off and ctls reset
+mux_errorcb(unsigned unit)
+{
+	/*
+	 * XXX: should stop only failed unit, not all devices
 	 */
-	ev.cmd = EV_XCTL;
-	ev.dev = unit;
-	ev.ctl_num = 120;		/* all sound off */
-	ev.ctl_val = 0;
-	for (i = 0; i <= EV_MAXCH; i++) {
-		ev.ch = i;
-		mux_ops->ev(mux_addr, &ev);
-	}
-	ev.ctl_num = 121;		/* all ctl reset */
-	ev.ctl_val = 0;
-	for (i = 0; i <= EV_MAXCH; i++) {
-		ev.ch = i;
-		mux_ops->ev(mux_addr, &ev);
-	}
+	norm_shut();
 	mux_flush();
 }
 
-/*
- * loops forever (actually until interrupt is received) and process
- * all events
- */
-void
-mux_run(void) {
-	mux_mdep_run();
-	
-	if (!mididev_master) {
-		if (mux_phase > MUX_START && mux_phase < MUX_STOP) {
-			mux_chgphase(MUX_STOP);
-			mux_ops->stop(mux_addr);
-			mux_sendstop();
-			mux_flush();
-		}
-	}
-}
-
-
 /*
  * called when an sysex has been received from an external device
  */
 void
-mux_sysexcb(unsigned unit, struct sysex *sysex) {
-	mux_ops->sysex(mux_addr, sysex);
+mux_sysexcb(unsigned unit, struct sysex *sysex)
+{
+	unsigned char *data;
+
+	/*
+	 * discard real-time messages, that should not be
+	 * recorded
+	 */
+	if (sysex->first != NULL &&
+	    sysex->first->next == NULL &&
+	    sysex->first->used >= 6) {
+		data = sysex->first->data;
+		if (data[0] == 0xf0 &&
+		    data[1] == 0x7f &&
+		    data[3] == 1) {
+			sysex_del(sysex);
+			return;
+		}
+	}
+	song_sysexcb(usong, sysex);
 }
 
 /*
  * flush all devices
  */
 void
-mux_flush(void) {
+mux_flush(void)
+{
 	struct mididev *dev;
+
 	for (dev = mididev_list; dev != NULL; dev = dev->next) {
-		rmidi_flush(RMIDI(dev));
+		mididev_flush(dev);
 	}
 }
 
@@ -587,7 +688,8 @@ mux_flush(void) {
  * return the current phase
  */
 unsigned
-mux_getphase(void) {
+mux_getphase(void)
+{
 	return mux_phase;
 }
 
@@ -596,7 +698,8 @@ mux_getphase(void) {
  * microseconds
  */
 void
-mux_chgtempo(unsigned long ticlength) {
+mux_chgtempo(unsigned long ticlength)
+{
 	if (mux_phase == MUX_FIRST || mux_phase == MUX_NEXT) {
 		mux_nextpos += ticlength;
 		mux_nextpos -= mux_ticlength;
@@ -609,24 +712,91 @@ mux_chgtempo(unsigned long ticlength) {
  * instance that 1 of "our"ticks equals 2 ticks on that device...
  */
 void
-mux_chgticrate(unsigned tpu) {
+mux_chgticrate(unsigned tpu)
+{
 	mux_ticrate = tpu;
 }
 
 /*
- * start waiting for a MIDI START event (or start immediately if
- * we're the clock master)
+ * start waiting for a MIDI START event (or generate one if
+ * we're the clock master).
  */
 void
-mux_startwait(void) {
+mux_startreq(void)
+{
+	struct mididev *dev;
+	static unsigned char mmc_start[] = { 0xf0, 0x7f, 0x7f, 0x06, 0x02, 0xf7 };
+
+	mux_reqphase = MUX_STARTWAIT;
+	if (mux_phase != MUX_STOP) {
+		dbg_puts("bad state to call mux_startreq()\n");
+		dbg_panic();
+	}
 	mux_chgphase(MUX_STARTWAIT);
+	if (!mididev_clksrc && !mididev_mtcsrc) {
+		if (mux_debug)
+			dbg_puts("mux_startreq: generated mtc start\n");
+		mux_curpos = 0;
+		mux_nextpos = MUX_START_DELAY;
+		mux_mtcstart(0xdeadbeef);
+	} else {
+		mux_curpos = 0;
+		mux_nextpos = mux_ticlength;
+	}
+
+	for (dev = mididev_list; dev != NULL; dev = dev->next) {
+		if (dev->sendmmc)
+			mididev_sendraw(dev, mmc_start, sizeof(mmc_start));
+	}
 }
 
 /*
- * start waiting for a MIDI STOP event (or stop immediately if we're
- * the clock master)
+ * stop the MIDI clock
  */
 void
-mux_stopwait(void) {
-	mux_chgphase(MUX_STOPWAIT);
+mux_stopreq(void)
+{
+	struct mididev *dev;
+	static unsigned char mmc_stop[] = { 0xf0, 0x7f, 0x7f, 0x06, 0x01, 0xf7 };
+
+	mux_reqphase = MUX_STOP;
+	if (mux_phase > MUX_START && mux_phase < MUX_STOP)
+		mux_sendstop();
+	if (mux_phase < MUX_STOP)
+		mux_stopcb();
+
+	for (dev = mididev_list; dev != NULL; dev = dev->next) {
+		if (dev->sendmmc)
+			mididev_sendraw(dev, mmc_stop, sizeof(mmc_stop));
+	}
 }
+
+/*
+ * relocate MIDI clock to given position
+ */
+void
+mux_gotoreq(unsigned mmcpos)
+{
+	struct mididev *dev;
+	unsigned char mmc_reloc[13];
+
+	mmc_reloc[0] =  0xf0;
+	mmc_reloc[1] =  0x7f;
+	mmc_reloc[2] =  0x7f;
+	mmc_reloc[3] =  0x06;
+	mmc_reloc[4] =  0x44;
+	mmc_reloc[5] =  0x06;
+	mmc_reloc[6] =  0x01;
+	mmc_reloc[7] =  (mmcpos / (3600 * MTC_SEC))	% 24;
+	mmc_reloc[8] =  (mmcpos / (60   * MTC_SEC))	% 60;
+	mmc_reloc[9] =  (mmcpos / MTC_SEC)		% 60;
+	mmc_reloc[10] = (mmcpos / (MTC_SEC / 24))	% 24; 
+	mmc_reloc[11] = (mmcpos / (MTC_SEC / 24 / 100)) % 100;
+	mmc_reloc[12] = 0xf7;
+
+	for (dev = mididev_list; dev != NULL; dev = dev->next) {
+		if (dev->sendmmc)
+			mididev_sendraw(dev, mmc_reloc, sizeof(mmc_reloc));
+	}
+}
+
