@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -46,25 +46,26 @@ struct node_vmt {
 	unsigned (*exec)(struct node *, struct exec *, struct data **);
 };
 
-struct node *node_new(struct node_vmt *vmt, struct data *data);
-void	     node_delete(struct node *o);
-void	     node_dbg(struct node *o, unsigned depth);
-void	     node_insert(struct node **n, struct node *e);
-void	     node_replace(struct node **n, struct node *e);
+struct node *node_new(struct node_vmt *, struct data *);
+void	     node_delete(struct node *);
+void	     node_dbg(struct node *, unsigned);
+void	     node_insert(struct node **, struct node *);
+void	     node_replace(struct node **, struct node *);
 unsigned     node_exec(struct node *, struct exec *, struct data **);
 
 
-extern struct node_vmt 
-	node_vmt_proc, node_vmt_alist, node_vmt_slist,
+extern struct node_vmt
+	node_vmt_proc, node_vmt_slist,
 	node_vmt_call, node_vmt_elist, node_vmt_builtin,
-	node_vmt_cst, node_vmt_var, node_vmt_list,
-	node_vmt_eq, node_vmt_neq, node_vmt_le, node_vmt_lt, node_vmt_ge, node_vmt_gt,
-	node_vmt_ignore, node_vmt_if, node_vmt_for, 
+	node_vmt_cst, node_vmt_var, node_vmt_list, node_vmt_range,
+	node_vmt_eq, node_vmt_neq, node_vmt_le,
+	node_vmt_lt, node_vmt_ge, node_vmt_gt,
+	node_vmt_ignore, node_vmt_if, node_vmt_for,
 	node_vmt_return, node_vmt_exit, node_vmt_assign, node_vmt_nop,
-	node_vmt_and, node_vmt_or, node_vmt_not, 
-	node_vmt_neg, node_vmt_add, node_vmt_sub, 
+	node_vmt_and, node_vmt_or, node_vmt_not,
+	node_vmt_neg, node_vmt_add, node_vmt_sub,
 	node_vmt_mul, node_vmt_div, node_vmt_mod,
-	node_vmt_lshift, node_vmt_rshift, 
+	node_vmt_lshift, node_vmt_rshift,
 	node_vmt_bitand, node_vmt_bitor, node_vmt_bitxor, node_vmt_bitnot;
 
 #endif /* MIDISH_NODE_H */
