@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -34,7 +34,7 @@
  *
  * endl:	"\n"
  * 		";"
- * 
+ *
  * cst:		num
  * 		string
  * 		ident
@@ -43,44 +43,44 @@
  * 		"[" call "]"
  * 		"(" expr ")"
  * 		"{" [ expr expr ...  expr ] "}"
- * 
+ *
  * unary:	"-" unary
  * 		"~" unary
  * 		"!" unary
  * 		cst
- * 
+ *
  * muldiv:	unary "*" unary
  * 		unary "/" unary
  * 		unary "%" unary
- * 	
+ *
  * addsub:	muldiv "+" muldiv
  * 		muldiv "-" muldiv
- * 	
+ *
  * shift:	addsub "<<" addsub
  * 		addsub ">>" addsub
- * 	
+ *
  * compare:	shift "<" shift
- * 		shift ">" shift 
+ * 		shift ">" shift
  * 		shift "<=" shift
  * 		shift ">=" shift
- * 	
+ *
  * equal:	compare "==" compare
  * 		compare "!=" compare
- * 	
+ *
  * bitand:	equal "&" equal
- * 	
- * bitxor:	bitand "^" bitand	
- * 	
+ *
+ * bitxor:	bitand "^" bitand
+ *
  * bitor:	bitxor "|" bitxor
- * 	
+ *
  * and:		bitor "&&" bitor
- * 	
+ *
  * or:		and "||" and
- * 
+ *
  * expr:	or
- * 
+ *
  * call:	ident [ expr expr ... expr ]
- * 
+ *
  * stmt:	"let" ident "=" expr endl
  * 		"for" ident "in" expr slist endl
  * 		"if" expr slist [ else slist ] endl
@@ -88,15 +88,15 @@
  * 		"return" expr endl
  * 		call endl
  * 		endl
- * 		
+ *
  * slist:	"{" [ stmt stmt ... stmt ] "}"
- * 
+ *
  * proc:	"proc" ident [ ident ident ... ident ] slist
- * 
+ *
  * line:	proc
  * 		stmt
  *
- * prog:	[ line line ... line ] EOF 		
+ * prog:	[ line line ... line ] EOF
  */
 
 #include "dbg.h"
@@ -111,7 +111,8 @@
 /* ------------------------------------------------------------- */
 
 void
-parse_recover(struct parse *o, char *msg) {
+parse_recover(struct parse *o, char *msg)
+{
 	lex_err(&o->lex, msg);
 	for (;;) {
 		if (o->lex.id == TOK_EOF) {
@@ -128,9 +129,11 @@ parse_recover(struct parse *o, char *msg) {
 }
 
 struct parse *
-parse_new(char *filename) {
+parse_new(char *filename)
+{
 	struct parse *o;
-	o = (struct parse *)mem_alloc(sizeof(struct parse));	
+
+	o = mem_alloc(sizeof(struct parse), "parse");
 	if (!lex_init(&o->lex, filename)) {
 		mem_free(o);
 		return 0;
@@ -140,13 +143,15 @@ parse_new(char *filename) {
 }
 
 void
-parse_delete(struct parse *o) {
+parse_delete(struct parse *o)
+{
 	lex_done(&o->lex);
 	mem_free(o);
 }
 
 unsigned
-parse_getsym(struct parse *o) {
+parse_getsym(struct parse *o)
+{
 	if (o->lookavail) {
 		o->lookavail = 0;
 		return 1;
@@ -155,16 +160,18 @@ parse_getsym(struct parse *o) {
 }
 
 void
-parse_ungetsym(struct parse *o) {
+parse_ungetsym(struct parse *o)
+{
 	if (o->lookavail) {
 		dbg_puts("parse_ungetsym: looksym already set\n");
 		dbg_panic();
 	}
-	o->lookavail = 1; 
+	o->lookavail = 1;
 }
 
 unsigned
-parse_isfirst(struct parse *o, unsigned *first) {
+parse_isfirst(struct parse *o, unsigned *first)
+{
 	while (*first != 0) {
 		if (*first == o->lex.id) {
 			return 1;
@@ -176,35 +183,42 @@ parse_isfirst(struct parse *o, unsigned *first) {
 
 /* ------------------------------------------------------------- */
 
-unsigned first_endl[] = {
+unsigned first_endl[] =
+{
 	TOK_ENDLINE, TOK_SEMICOLON, 0
 };
 
-unsigned first_proc[] = {
+unsigned first_proc[] =
+{
 	TOK_PROC, 0
 };
 
-unsigned first_assign[] = {
+unsigned first_assign[] =
+{
 	TOK_LET, 0
 };
 
-unsigned first_call[] = {
+unsigned first_call[] =
+{
 	TOK_IDENT, 0
 };
 
-unsigned first_expr[] = {
+unsigned first_expr[] =
+{
 	TOK_MINUS, TOK_EXCLAM, TOK_TILDE,
 	TOK_LPAR, TOK_DOLLAR, TOK_LBRACE, TOK_IDENT, TOK_NIL,
 	TOK_NUM, TOK_STRING, TOK_LBRACKET, 0
 };
 
-unsigned first_stmt[] = {
-	TOK_SEMICOLON, TOK_ENDLINE, 
+unsigned first_stmt[] =
+{
+	TOK_SEMICOLON, TOK_ENDLINE,
 	TOK_IF, TOK_FOR, TOK_IDENT, TOK_LET, TOK_RETURN, TOK_EXIT, 0
 };
-	 
+
 unsigned
-parse_endl(struct parse *o, struct node **n) {
+parse_endl(struct parse *o, struct node **n)
+{
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -216,9 +230,10 @@ parse_endl(struct parse *o, struct node **n) {
 }
 
 unsigned
-parse_cst(struct parse *o, struct node **n) {
+parse_cst(struct parse *o, struct node **n)
+{
 	struct data *data;
-		
+
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -315,7 +330,8 @@ parse_cst(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_unary(struct parse *o, struct node **n) {
+parse_unary(struct parse *o, struct node **n)
+{
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -345,10 +361,11 @@ parse_unary(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_muldiv(struct parse *o, struct node **n) {
+parse_muldiv(struct parse *o, struct node **n)
+{
 	if (!parse_unary(o, n)) {
 		return 0;
-	}	
+	}
 	for (;;) {
 		if (!parse_getsym(o)) {
 			return 0;
@@ -378,7 +395,8 @@ parse_muldiv(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_addsub(struct parse *o, struct node **n) {
+parse_addsub(struct parse *o, struct node **n)
+{
 	if (!parse_muldiv(o, n)) {
 		return 0;
 	}
@@ -406,7 +424,8 @@ parse_addsub(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_shift(struct parse *o, struct node **n) {
+parse_shift(struct parse *o, struct node **n)
+{
 	if (!parse_addsub(o, n)) {
 		return 0;
 	}
@@ -434,7 +453,8 @@ parse_shift(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_compare(struct parse *o, struct node **n) {
+parse_compare(struct parse *o, struct node **n)
+{
 	if (!parse_shift(o, n)) {
 		return 0;
 	}
@@ -472,7 +492,8 @@ parse_compare(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_equal(struct parse *o, struct node **n) {
+parse_equal(struct parse *o, struct node **n)
+{
 	if (!parse_compare(o, n)) {
 		return 0;
 	}
@@ -500,7 +521,8 @@ parse_equal(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_bitand(struct parse *o, struct node **n) {
+parse_bitand(struct parse *o, struct node **n)
+{
 	if (!parse_equal(o, n)) {
 		return 0;
 	}
@@ -523,7 +545,8 @@ parse_bitand(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_bitxor(struct parse *o, struct node **n) {
+parse_bitxor(struct parse *o, struct node **n)
+{
 	if (!parse_bitand(o, n)) {
 		return 0;
 	}
@@ -546,7 +569,8 @@ parse_bitxor(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_bitor(struct parse *o, struct node **n) {
+parse_bitor(struct parse *o, struct node **n)
+{
 	if (!parse_bitxor(o, n)) {
 		return 0;
 	}
@@ -569,7 +593,8 @@ parse_bitor(struct parse *o, struct node **n) {
 
 
 unsigned
-parse_and(struct parse *o, struct node **n) {
+parse_and(struct parse *o, struct node **n)
+{
 	if (!parse_bitor(o, n)) {
 		return 0;
 	}
@@ -591,7 +616,8 @@ parse_and(struct parse *o, struct node **n) {
 }
 
 unsigned
-parse_or(struct parse *o, struct node **n) {
+parse_or(struct parse *o, struct node **n)
+{
 	if (!parse_and(o, n)) {
 		return 0;
 	}
@@ -613,15 +639,43 @@ parse_or(struct parse *o, struct node **n) {
 }
 
 unsigned
-parse_expr(struct parse *o, struct node **n) {
-	return parse_or(o, n);
+parse_exprange(struct parse *o, struct node **n)
+{
+	if (!parse_or(o, n)) {
+		return 0;
+	}
+	if (!parse_getsym(o)) {
+		return 0;
+	}
+	if (o->lex.id == TOK_RANGE) {
+		node_replace(n, node_new(&node_vmt_range, NULL));
+		if (!parse_or(o, &(*n)->list->next)) {
+			return 0;
+		}
+		if (!parse_getsym(o)) {
+			return 0;
+		}
+		if (o->lex.id == TOK_RANGE) {
+			parse_recover(o, "too many '..' for range");
+			return 0;
+		}
+	}
+	parse_ungetsym(o);
+	return 1;
 }
 
 unsigned
-parse_call(struct parse *o, struct node **n) {
+parse_expr(struct parse *o, struct node **n)
+{
+	return parse_exprange(o, n);
+}
+
+unsigned
+parse_call(struct parse *o, struct node **n)
+{
 	if (!parse_getsym(o)) {
 		return 0;
-	} 
+	}
 	if (o->lex.id != TOK_IDENT) {
 		return 0;
 	}
@@ -645,7 +699,8 @@ parse_call(struct parse *o, struct node **n) {
 }
 
 unsigned
-parse_stmt(struct parse *o, struct node **n) {
+parse_stmt(struct parse *o, struct node **n)
+{
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -739,7 +794,7 @@ parse_stmt(struct parse *o, struct node **n) {
 		if (o->lex.id != TOK_ASSIGN) {
 			parse_recover(o, "'=' expected");
 			return 0;
-		}	
+		}
 		if (!parse_getsym(o)) {
 			return 0;
 		}
@@ -774,7 +829,8 @@ parse_stmt(struct parse *o, struct node **n) {
 }
 
 unsigned
-parse_slist(struct parse *o, struct node **n) {
+parse_slist(struct parse *o, struct node **n)
+{
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -801,26 +857,10 @@ parse_slist(struct parse *o, struct node **n) {
 }
 
 unsigned
-parse_alist(struct parse *o, struct node **n) {
-	*n = node_new(&node_vmt_alist, NULL);
-	n = &(*n)->list;
-	for(;;) {
-		if (!parse_getsym(o)) {
-			return 0;
-		}
-		if (o->lex.id != TOK_IDENT) {
-			parse_ungetsym(o);
-			break;
-		}
-		*n = node_new(&node_vmt_cst, data_newref(o->lex.strval));
-		n = &(*n)->next;
-	}	
-	return 1;
-}
+parse_proc(struct parse *o, struct node **n)
+{
+	struct data *args;
 
-unsigned
-parse_proc(struct parse *o, struct node **n) {	
-	struct node **a;
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -835,16 +875,15 @@ parse_proc(struct parse *o, struct node **n) {
 		parse_recover(o, "proc name expected");
 		return 0;
 	}
-	*n = node_new(&node_vmt_proc, data_newref(o->lex.strval));
-	(*n)->list = node_new(&node_vmt_alist, NULL);
-	a = &(*n)->list->list;
+	args = data_newlist(NULL);
+	data_listadd(args, data_newstring(o->lex.strval));
+	*n = node_new(&node_vmt_proc, args);
 	for(;;) {
 		if (!parse_getsym(o)) {
 			return 0;
 		}
 		if (o->lex.id == TOK_IDENT) {
-			*a = node_new(&node_vmt_cst, data_newref(o->lex.strval));
-			a = &(*a)->next;
+			data_listadd(args, data_newstring(o->lex.strval));
 		} else if (o->lex.id == TOK_LBRACE) {
 			parse_ungetsym(o);
 			break;
@@ -853,18 +892,19 @@ parse_proc(struct parse *o, struct node **n) {
 			parse_recover(o, "argument name or block expected");
 			return 0;
 		}
-	}	
-	if (!parse_slist(o, &(*n)->list->next)) {
+	}
+	if (!parse_slist(o, &(*n)->list)) {
 		return 0;
 	}
 	if (!parse_endl(o, NULL)) {
 		return 0;
 	}
 	return 1;
-}	
+}
 
 unsigned
-parse_line(struct parse *o, struct node **n) {
+parse_line(struct parse *o, struct node **n)
+{
 	if (!parse_getsym(o)) {
 		return 0;
 	}
@@ -884,9 +924,10 @@ parse_line(struct parse *o, struct node **n) {
 	}
 	return 1;
 }
-	
+
 unsigned
-parse_prog(struct parse *o, struct node **n) {
+parse_prog(struct parse *o, struct node **n)
+{
 	*n = node_new(&node_vmt_slist, NULL);
 	n = &(*n)->list;
 	for (;;) {
