@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -59,7 +59,7 @@ unsigned      parse_assign(struct parse *, struct node **);
 unsigned      parse_stmt(struct parse *, struct node **);
 unsigned      parse_slist(struct parse *, struct node **);
 unsigned      parse_proc(struct parse *, struct node **);
-unsigned      parse_line(struct parse *o, struct node **n);
-unsigned      parse_prog(struct parse *o, struct node **n);
+unsigned      parse_line(struct parse *, struct node **);
+unsigned      parse_prog(struct parse *, struct node **);
 
 #endif /* MIDISH_PARSE_H */
