@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -43,22 +43,23 @@ struct songfilt;
 struct songsx;
 struct song;
 
-void ev_output(struct ev *e, struct textout *f);
-void track_output(struct track *t, struct textout *f);
-void rule_output(struct rule *o, struct textout *f);
-void filt_output(struct filt *o, struct textout *f);
-void songtrk_output(struct songtrk *o, struct textout *f);
-void songchan_output(struct songchan *o, struct textout *f);
-void songfilt_output(struct songfilt *o, struct textout *f);
-void songsx_output(struct songsx *o, struct textout *f);
-void evctltab_output(struct evctl *tab, struct textout *f);
-void song_output(struct song *o, struct textout *f);
+void ev_output(struct ev *, struct textout *);
+void evspec_output(struct evspec *, struct textout *);
+void track_output(struct track *, struct textout *);
+void rule_output(struct rule *, struct textout *);
+void filt_output(struct filt *, struct textout *);
+void songtrk_output(struct songtrk *, struct textout *);
+void songchan_output(struct songchan *, struct textout *);
+void songfilt_output(struct songfilt *, struct textout *);
+void songsx_output(struct songsx *, struct textout *);
+void evctltab_output(struct evctl *, struct textout *);
+void song_output(struct song *, struct textout *);
 
-void track_save(struct track *o, char *name);
-unsigned track_load(struct track *o, char *name);
+void track_save(struct track *, char *);
+unsigned track_load(struct track *, char *);
 
-void song_save(struct song *o, char *name);
-unsigned song_load(struct song *o, char *filename);
+void song_save(struct song *, char *);
+unsigned song_load(struct song *, char *);
 
 
 #endif /* MIDISH_SAVELOAD_H */
