@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -33,7 +33,7 @@
 
 struct song;
 
-unsigned song_exportsmf(struct song *o, char *filename);
-struct song *song_importsmf(char *filename);
+unsigned song_exportsmf(struct song *o, char *);
+struct song *song_importsmf(char *);
 
 #endif /* MIDISH_SMF_H */
