@@ -1,9 +1,9 @@
 /*
- * Copyright (c) 2003-2007 Alexandre Ratchov <alex@caoua.org>
+ * Copyright (c) 2003-2010 Alexandre Ratchov <alex@caoua.org>
  * All rights reserved.
  *
- * Redistribution and use in source and binary forms, with or without 
- * modification, are permitted provided that the following conditions 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
  * are met:
  *
  * 	- Redistributions of source code must retain the above
@@ -48,23 +48,23 @@ struct sysexlist {
 	struct sysex *first, **lastptr;
 };
 
-void 	      chunk_pool_init(unsigned size);
+void 	      chunk_pool_init(unsigned);
 void 	      chunk_pool_done(void);
 struct chunk *chunk_new(void);
-void	      chunk_del(struct chunk *o);
+void	      chunk_del(struct chunk *);
 
-void	      sysex_pool_init(unsigned size);
+void	      sysex_pool_init(unsigned);
 void	      sysex_pool_done(void);
-struct sysex *sysex_new(unsigned unit);
-void	      sysex_del(struct sysex *o);
-void	      sysex_add(struct sysex *o, unsigned data);
-void	      sysex_dbg(struct sysex *o);
-unsigned      sysex_check(struct sysex *o);
+struct sysex *sysex_new(unsigned);
+void	      sysex_del(struct sysex *);
+void	      sysex_add(struct sysex *, unsigned);
+void	      sysex_dbg(struct sysex *);
+unsigned      sysex_check(struct sysex *);
 
-void 	      sysexlist_init(struct sysexlist *o);
-void	      sysexlist_done(struct sysexlist *o);
-void	      sysexlist_put(struct sysexlist *o, struct sysex *e);
-struct sysex *sysexlist_get(struct sysexlist *o);
-void	      sysexlist_dbg(struct sysexlist *o);
+void 	      sysexlist_init(struct sysexlist *);
+void	      sysexlist_done(struct sysexlist *);
+void	      sysexlist_put(struct sysexlist *, struct sysex *);
+struct sysex *sysexlist_get(struct sysexlist *);
+void	      sysexlist_dbg(struct sysexlist *);
 
 #endif /* MIDISH_SYSEX_H */
